#include <iostream.h>
#include <stddef.h>
#include <strstream.h>
#include <string.h>
#include <stdio.h>

#include "docdisplay.h"
#include "cmcPersistentCollection.h"
#include "cmcAttribute.h"
#include "cmcAttributeValue.h"
#include "cmcStringValue.h"
#include "cmcSequenceValue.h"

// struct MenuOpts describes options from the menu 
struct MenuOpts
{
    char               *description;	// description of menu options 
    void                (*function) ();	// function to do option 
};

static PersistentCollection *Data[20];		// test data


static int FindMenuSize(struct MenuOpts *menu_p);
static void DisplayMenu(struct MenuOpts *menu_p);
static void TestConstructNew(void);
static void TestConstructOld(void);
static void TestDestruct(void);
static void TestLength(void);
static void TestRemoveDocument(void);
static void TestGetDocument(void);
static void TestFirstDocument(void);
static void TestNextDocument(void);
static void TestGetByExternalId(void);
static void TestAnnotateCollection(void);
static void TestSync(void);
static void TestDestroy(void);
static void TestPutAttribute(void);
static void TestGetAttribute(void);
static void TestGetAttributes(void);
static void TestStore(void);
static void TestCreateDocument(void);
static void TestChangeExternalId(void);
static void TestListExternalIds(void);
static void GetAttributeString(char *);
static void GetAttributeValue(char *);
static void GetDocumentString(char *);

// main performs the test
main(int argc, char *argv[])
{
    int                 menu_size;     	// size of menu 
    int                 choice;	       	// user choice 
    static struct MenuOpts menu[]  	// test menu 
    = {
	{"Open a new collection", TestConstructNew},
	{"Open an existing collection", TestConstructOld},
	{"Delete an existing collection", TestDestroy},
	{"Count Documents", TestLength},
	{"Create Document", TestCreateDocument},
	{"Remove Document", TestRemoveDocument},
	{"Get Document by Internal ID",  TestGetDocument},
	{"Get Document by External ID", TestGetByExternalId},
	{"Get First Document", TestFirstDocument},
	{"Get Next Document", TestNextDocument},
//	{"AnnotateCollection()", TestAnnotateCollection},
	{"Sync Collection to Disk", TestSync},
	{"Add Attribute", TestPutAttribute},
	{"Get Attribute", TestGetAttribute},
	{"List All Attributes", TestGetAttributes},
	{"Change External ID", TestChangeExternalId},
	{"List External IDs", TestListExternalIds},
	{NULL, NULL}};

    choice = -1;
    while (choice != 0) 
    { 
	// display choices 
	DisplayMenu(menu);

        // get size of menu 
        menu_size = FindMenuSize(menu);

	// get and process choice 
	cin >> choice;
	if (choice < 0 || choice > menu_size + 1)
	    cout << "Invalid option: try again\n";
	else if (choice > 0)
	    (*menu[choice - 1].function) ();
    }
}



// FindMenuSize() returns the number of items on the menu
static int FindMenuSize(struct MenuOpts *menu_p)
{
    int                 size = 0;      // to hold size 

    if (Data[0] == NULL)
       size = 2;
    else
    {
    while (menu_p->description != NULL)
    {
	++menu_p;
	++size;
    }
    }

    return (size);
}



// DisplayMenu() displays the menu to the user
static void DisplayMenu(struct MenuOpts *menu_p)
{
    int                 ctr;	       	// to count options 

    ctr = 1;
    cout << "\t0\tQuit\n";

    if (Data[0] == NULL)
    {
       for ( /* no initialize */ ; ctr < 3; menu_p++, ctr++)
       {
   	   cout << "\t" << ctr << "\t" << menu_p->description << "\n";
       }
    }
    else
    {
    for ( /* no initialize */ ; menu_p->description != NULL; menu_p++, ctr++)
    {
	cout << "\t" << ctr << "\t" << menu_p->description << "\n";
    }
    }
    cout << "\nChoose one: ";
}


static void TestConstructNew(void)
{
    int index;				// data to test
    int count;				// count of Attributes
    Set<Attribute> Attributes;		// the Attributes
    char Name[200];			// name of the Collection
    // int VolumeCount;			// count of Volumes
    // int BlockSize;			// size of data blocks

    index = 0;

    cout << "Enter name: ";
    cin >> Name;
    cout << "Enter Attribute count: ";
    cin >> count;

    for(int i = 0; i < count; ++i)
    {
	char string[1000];		// attribute buffer string
	istrstream Input(string, 1000);	// buffer version of string

        GetAttributeString(string);

	Attributes.Push(new Attribute(Input));
    }

    Data[index] = new PersistentCollection(Name, Attributes
	//, VolumeCount, BlockSize);
	);
}




static void TestConstructOld(void)
{
    int index;				// data to test
    char Name[200];			// name of Collection

    // cout << "Enter index: ";
    // cin >> index;
    index = 0;

    cout << "Enter name: ";
    cin >> Name;

    try
    {
       Data[index] = new PersistentCollection(Name);
    }
    catch(...)
    {
       cout << "Collection not found.\n";
    }
}


static void TestDestruct(void)
{
    int index;				// data to test

    // cout << "Enter index: ";
    // cin >> index;
    index = 0;

    delete Data[index];
    Data[index] = NULL;
}


static void TestLength(void)
{
    int index;				// data to test

    // cout << "Enter index: ";
    // cin >> index;
    index = 0;
 
    if (Data[index] == NULL)
       cout << "No open collection - This action is not valid.\n\n";
    else
       cout << "Results: " << Data[index]->Length() << "\n\n";
}


static void TestRemoveDocument(void)
{
    int index;				// data to test
    char Id[100];			// id of document to remove

    // cout << "Enter index: ";
    // cin >> index;
    index = 0;

    cout << "Enter ID: ";
    cin >> Id;

    Data[index]->RemoveDocument(Id);
}


static void TestGetDocument(void)
{
    int index;				// data to test
    char Id[100];			// id of document to remove

    // cout << "Enter index: ";
    // cin >> index;
    index = 0;

    cout << "Enter ID: ";
    cin >> Id;

    Document *pD = Data[index]->GetDocument(Id);

    if(pD == NULL)
	cout << "Not found\n";
    else
    {
	cout << "Result: \"";
	ShowDocument(*pD);
//	pD->WriteToStream(cout);
	cout << "\"\n";
	delete pD;
    }
}


static void TestFirstDocument(void)
{
    int index;				// data to test

    // cout << "Enter index: ";
    // cin >> index;
    index = 0;

    
    Document *pD = Data[index]->FirstDocument();

    if(pD == NULL)
	cout << "Not found\n";
    else
    {
	cout << "Result: \"";
	ShowDocument(*pD); 
	//pD->WriteToStream(cout); 
	cout << "\"\n";
	delete pD;
    }
}


static void TestNextDocument(void)
{
    int index;				// data to test

    // cout << "Enter index: ";
    // cin >> index;
    index = 0;

    
    Document *pD = Data[index]->NextDocument();

    if(pD == NULL)
	cout << "Not found\n";
    else
    {
	cout << "Result: \"";
	ShowDocument(*pD); 
	//pD->WriteToStream(cout);
	cout << "\"\n";
	delete pD;
    }
}


static void TestGetByExternalId(void)
{
    int index;				// data to test
    char Id[100];			// id of document to remove

    // cout << "Enter index: ";
    // cin >> index;
    index = 0;

    cout << "Enter ID: ";
    cin >> Id;

    Document *pD = Data[index]->GetByExternalId(Id);

    if(pD == NULL)
	cout << "Not found\n";
    else
    {
	cout << "Result: \"";
	pD->WriteToStream(cout);
	cout << "\"\n";
	delete pD;
    }
}


static void TestAnnotateCollection(void)
{
    int index;				// data to test
    int whichIndex;			// index of Which collection
    char name[100];			// annotator name

    // cout << "Enter index: ";
    // cin >> index;
    index = 0;

    // cout << "Enter index of which collection: ";
    // cin >> whichIndex;
    whichIndex = 0;
    cout << "Enter annotator name: ";
    cin >> name;

    Data[index]->AnnotateCollection(*Data[whichIndex], name);
}



static void TestSync(void)
{
    int index;				// data to test

    // cout << "Enter index: ";
    // cin >> index;
    index = 0;


    Data[index]->Sync();
}




static void TestDestroy(void)
{
    char Name[200];			// Collection to destroy

    cout << "Enter name: ";
    cin >> Name;

    PersistentCollection::Destroy(Name);
}



static void TestStore(void)
{
    int index;				// data to test
    char buffer[1000];			// place to put input string
    istrstream Input(buffer, 1000);	// stream version of it
    char ch;				// filler character

    index = 0;

    GetDocumentString(buffer);
    Document *pDoc = new Document(*Data[index], Input);

    cout << "New ID is : \"" << pDoc->GetId() << "\"\n";
}


static void TestPutAttribute(void)
{
    int index;                          // index of data
    char buffer[1000];                  // attribute buffer
    char name[1000];                     // attribute name
    istrstream input(buffer, 1000);     // the input buffer
    char ch;                            // to hold character
 
    // cout << "Enter index: ";
    // cin >> index;
    index = 0;


    cin.get(ch);
    cout << "Enter attribute name: ";
    cin.getline(name, sizeof(name));
    GetAttributeValue(buffer);
 
    Data[index]->PutAttribute(name, *ReadAttributeValue(input));
}
 
 
static void TestGetAttribute(void)
{
    int index;                  // index of data
    char name[100];             // name of attribute to get
 
    // cout << "Enter index: ";
    // cin >> index;
    index = 0;

    cout << "Enter name: ";
    cin >> name;
 
    const AttributeValue *v = Data[index]->GetAttribute(name);
  // consider using Attribute::WriteToStream method here. 
    if (v == NULL)
       cout << "Attribute " << name << " not found.\n";
    else
       cout << "\"" << *v << "\"\n";
}


static void TestGetAttributes(void)
{
    int index;                  // index of data
    Set<Attribute> *attrs;      // attribute set

    // cout << "Enter index: ";
    // cin >> index;
    index = 0;


    attrs = &Data[index]->GetAttributes();

    cout << "Count is " << attrs->Length() << "\n";
    for(int i = 0; i < attrs->Length(); ++i)
    {
        cout << "\t" << i << " \"" << attrs->Nth(i) << "\"\n";
    }
}




static void TestCreateDocument(void)
{
    int index;				// index of data
    char filename[100];			// name of file to use
    char chExtId[100];
    char answer[4];
    char data[100000];
    char ch;
    AnnotationSet anns;
    Set<Attribute> atts;
    ByteSequence *pBs;

    index = 0;

    cin.get(ch);  // get the extra nl char
    cout << "Enter external id of new document: ";
    cin.getline(chExtId, sizeof(chExtId));

    cout << "Read document text from file? [y/n]: ";
    cin.getline(answer, sizeof(answer));
    if ((answer[0] == 'y') || (answer[0] == 'Y'))
    {
       cout << "Enter document filename: ";
       cin >> filename;

       ifstream in(filename);
	int length;

	in.read(data, 99999);
        pBs = new ByteSequence(data, in.gcount());
    }
    else
    {
       cout << "Type document text: ";
       cin.get(ch);
       cin.getline(data, sizeof(data));
       pBs = new ByteSequence(data, strlen(data));
    }



    Document *d = new Document(*Data[index], chExtId, pBs, anns, atts);
    d->Sync();
    delete pBs;
    delete d;
}



static void TestChangeExternalId(void)
{
    int index;				// index of data
    char oldextid[100];			// old external id
    char newextid[100];			// new external id

    // cout << "Enter index: ";
    // cin >> index;
    index = 0;

    cout << "Enter old external id: ";
    cin >> oldextid;
    cout << "Enter new external id: ";
    cin >> newextid;

    Document *pDoc = Data[index]->GetByExternalId(oldextid);

    if (pDoc == NULL)
       cout << " Document not found." << endl;
    else
    {
       pDoc->SetExternalId(newextid);

       pDoc->Sync();

       Data[index]->Sync();

       delete pDoc;
    }
}



static void TestListExternalIds(void)
{
    int index;			// index of data
    Document *pDocument;	// document to use

    // cout << "Enter index: ";
    // cin >> index;
    index = 0;


    cout << " Internal Id \t-\t External Id " << endl;

    pDocument = Data[index]->FirstDocument();
    while(pDocument != NULL)
    {
	cout << "  " << pDocument->GetExternalId() << "\t\t-\t "
		<< pDocument->GetId() << endl;

	//if(pDocument->GetExternalId() != NULL)
	//{
	    //Document *pD2 = Data[index]->GetByExternalId(
			//pDocument->GetExternalId());
	    //if(pD2 != NULL)
	    //{
		//cout << "Get by ext id gets document: " <<
			//pDocument->GetId() << endl;
		//delete pD2;
	    //}
	    //else
		//cout << "No get by ext id\n";
	//}

	delete pDocument;

	pDocument = Data[index]->NextDocument();
    }
    cout << endl;
}







void GetAttributeString(char *string)
{
	char ch;			// input character
        char AttName[100], AttValue[100];
        int AttTypeNumber;
        char Length[100];

	cout << "Enter attribute Name: ";
        cin.get();  // pick off previous nl 
        cin.getline(AttName, sizeof(AttName));
        sprintf(Length, "%d", strlen(AttName));
        strcpy(string, Length);
        strcat(string, " ");
        strcat(string, AttName);
        strcat(string, " ");

        GetAttributeValue(AttValue);
        strcat(string, AttValue);
}



void GetDocumentString(char *string)
{
	char ch;			// input character
        char Text[1000];
        char Length[5];

        cin.get(ch);  // clear the nl
	cout << "Enter Internal id: ";
        cin.getline(Text, sizeof(Text));
        sprintf(Length, "%d", strlen(Text));
        strcpy(string, Length);
        strcat(string, " ");
        strcat(string, Text);

	cout << "Enter External Id: ";
        cin.getline(Text, sizeof(Text));
        sprintf(Length, "%d", strlen(Text));
        strcat(string, Length);
        strcat(string, " ");
        strcat(string, Text);

        strcat(string, "1");
	cout << "Enter Document text: ";
        cin.getline(Text, sizeof(Text));
        sprintf(Length, "%d", strlen(Text));
        strcat(string, Length);
        strcat(string, " ");
        strcat(string, Text);

        // now annotations
        strcat(string, "0 ");
        // now attrbutes
        strcat(string, "0 ");
}


void GetAttributeValue(char *string)
{
	char ch;			// input character
        char AttValue[1000];
        char Length[5];

  	strcpy(string, "s ");
        
	cout << "Enter attribute Value: ";
        cin.getline(AttValue, sizeof(AttValue));
        sprintf(Length, "%d", strlen(AttValue));
        strcat(string, Length);
        strcat(string, " ");
        strcat(string, AttValue);
}

#if 0
void GetAttributeValue(char *string)
{
	char ch;			// input character
        char AttValue[1000];
        int AttTypeNumber;
        char Length[5];

        cout << "Select Attribute Type:\n";
        cout << "1. String\n2. Sequence\n3. Collection Reference\n";
        cout << "4. Document Reference\n5. Annotation Reference\n";
        cout << "6. Attribute Reference\nType: ";
        cin >> AttTypeNumber;
        switch (AttTypeNumber)
        {
        case 1: 
  		strcpy(string, "s ");
                break;
        case 2: 
  		strcpy(string, "S ");
                break;
        case 3: 
  		strcpy(string, "C ");
                break;
        case 4: 
  		strcpy(string, "D ");
                break;
        case 5: 
  		strcpy(string, "A ");
                break;
        case 6: 
  		strcpy(string, "a ");
                break;
        default:
  		strcpy(string, "s ");
        }
        
	cout << "Enter attribute Value: ";
        cin >> AttValue;
        sprintf(Length, "%d", strlen(AttValue));
        strcat(string, Length);
        strcat(string, " ");
        strcat(string, AttValue);
}
#endif
