//
//
// Module Name:		cmcAnnotation.h
//
// CSCI/CSC/CSU:	CMC/Annotation.h
//
// Author:		Ken Kolda
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	Include file for Annotations.  An Annotation is a description of
//	part of a Document.
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           11/17/95    kolda    Initial version
//

#ifndef _cmcAnnotation_h
#define _cmcAnnotation_h

#include <iostream.h>			// used for input streams

#include "cmcSet.h"			// Spans are kept in Sets
#include "cmcAttributedObject.h"	// Annotation is a AttributedObject
#include "cmcAttribute.h"		// Annotations can have Attributes
#include "cmcSpan.h"			// Spans are used for Document locations
#include "cmcDocMgrObject.h"		// To get a base class

// Annotation is a set of highlights, or Spans, in a Document
#ifndef __GNUG__
class Annotation : public AttributedObject, public DocumentManagerObject
#else
class Annotation : public AttributedObject
#endif

{
  private:
	char *Id;			// ID of the Annotation
	char *Type;			// Type of Annotation
	Set<Span> Spans;		// The actual Document portions

  public:
	// TIPSTER calls
	Annotation(const char *NewType, const Set<Span> &NewSpans, 
		const Set<Attribute> &NewAttributes);
					// Constructor
	~Annotation(void);		// Destructor
	const char *GetId(void) const;	// Returns the Id component
	const char *GetType(void) const;// Returns the Type component
	Set<Span> &GetSpans(void);	// Returns the Spans component

	// TIPSTER add-ons
	static const char *ClassLabel;	// The name of this class

	Annotation(istream &);		// construct from input stream
	void SetId(const char *NewId);	// Sets the Id component
	Annotation *Copy(void) const;	// produce a copy of this
	int IsChanged(void) const;	// has this changed?
	void ClearChanged(void);	// clear changed status
	void WriteToStream(ostream&) const;
					// write to an output stream
	virtual const char *GetClass(void) const;
					// get the type of this
	virtual Annotation &CastToAnnotation(void);
					// downcast to Annotation
	virtual const Annotation &CastToAnnotation(void) const;
					// downcast to Annotation
};


// the following are associated functions
ostream &operator<<(ostream&, Annotation&);

#endif
