//
// Module Name:		cmcAnnotationReference.h
//
// CSCI/CSC/CSU:	CMC/AnnotationReference
//
// Author:		Ken Kolda
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	.h file for AnnotationReference.  An AnnotationReference is a
//	reference to an Annotation.
//
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           12/15/95    kolda    Initial version
//

#ifndef _cmcAnnotationReference_h
#define _cmcAnnotationReference_h

#include <iostream.h>			// for stream types

#include "cmcObjectReference.h"		// base class for this
#include "cmcAttributeValueType.h"	// to return a value type
#include "cmcDocument.h"		// used in a constructor
#include "cmcAnnotation.h"		// used in a constructor
#include "cmcDocMgrObject.h"		// Has a base class of this

// Provides an Attribute that is a reference to a CMC Attribute
#ifndef __GNUG__
class AnnotationReference : public ObjectReference, public DocumentManagerObject
#else
class AnnotationReference : public ObjectReference
#endif
{
  private:
	char *CollectionName;		// The Collection that contains the 
					// annotated document
	char *DocumentId;		// ID of the annotated Document  
	char *AnnotationId;		// ID of referenced annotation

	virtual void Write(ostream &Output) const;
					// write to output
	void Cleanup(void);		// clean out all memory stores for this

  public:
	// TIPSTER calls
	AnnotationReference(Document &ReferencedDocument, 
				Annotation &ReferencedAnnotation);
					// Constructor
	~AnnotationReference(void);	// Destructor
	const char *GetCollectionName(void) const;
					// Returns CollectionName component
	const char *GetDocumentId(void) const;
					// Returns the DocumentId component
	const char *GetAnnotationId(void) const;
					// Returns the AnnotationId component

	// TIPSTER additions	
	static const char *ClassLabel;	// The name of this class

	AnnotationReference(const char *NewCollectionName, 
				const char *NewDocumentId,
				const char *NewAnnotationId);
					// constructor
	AnnotationReference(istream &Input);
					// Construct from input
	AttributeValueType TypeOf(void) const;
					// Returns "AnnotationReference"
	virtual ObjectReference *Copy(void) const;
					// produce a copy of this
	virtual int operator==(const ObjectReference&) const;
					// test equality
	virtual const char *GetClass(void) const;
					// Get the class of this
	virtual AnnotationReference &CastToAnnotationReference(void);
					// downcast function
	virtual const AnnotationReference &CastToAnnotationReference(void) 
			const;
					// downcast function
};

#endif
