//
//
// Module Name:		cmcAnnotationSet.h
//
// CSCI/CSC/CSU:	CMC/AnnotationSet
//
// Author:		Ken Kolda
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	.h for AnnotationSet.  An AnnotationSet is a group of Annotations.
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           11/17/95    kolda    Initial version
//

#ifndef _cmcAnnotationSet_h
#define _cmcAnnotationSet_h

#include <iostream.h>			// used for input streams

class AnnotationSet;			// forward declaration

#include "cmcSet.h"			// Annotations are kept in Sets
#include "cmcAnnotation.h"		// This stores Annotations
#include "cmcDocMgrObject.h"		// Has a base class of this

// AnnotationSet is a Set of Annotations along with functions for manipulating
// them
class AnnotationSet : public DocumentManagerObject
{
  private:
	Set<Annotation> Members;	// The Set of Annotations
	int LastAnnotationId;		// Counter
	int Changed;			// Changed flag

  public:
	// TIPSTER calls
	AnnotationSet(void);		// Constructor
	~AnnotationSet(void);		// Destructor
	void RemoveAnnotation(const char *Id);
					// Removes Annotation from Set
	Annotation &GetAnnotation(const char *Id) const;
					// Retrieves the named Annotation
	int Length(void) const;		// Returns number of Annotations in Set
	Annotation &Nth(int i) const;	// Returns ith Annotation
	AnnotationSet *SelectAnnotations(const char *Type, 
		Set<Attribute> &Constraints) const;
					// Returns subset of Annotations
					// that matches given criteria
	void DeleteAnnotations(const char *Type, Set<Attribute> &Constraints);
					// Deletes Annotations matching
					// the given criteria
	AnnotationSet *AnnotationsAt(int Position) const;
					// Returns Annotations that start
					// at specified position
	AnnotationSet *NextAnnotations(int Position) const;
					// Returns first Annotations that
					// start on or after position
	AnnotationSet *MergeAnnotations(AnnotationSet &NewAnnotations) const;
					// Returns current Annotations
					// merged with NewAnnotations

	// TIPSTER additions
	static const char *ClassLabel;	// The name of this class

	AnnotationSet(istream &);	// Construct from input
	AnnotationSet(const AnnotationSet&);
					// Copy constructor
	const char *AddAnnotation(Annotation &NewAnnotation);
					// Adds Annotation to Set
	AnnotationSet *Copy(void) const;
					// copy this
	void WriteToStream(ostream&) const;
					// write this to a stream
	int IsChanged(void) const;	// see if this has changed
	void ClearChanged(void);	// clear the Changed flag

	virtual const char *GetClass(void) const;
					// Get the class of this
	virtual AnnotationSet &CastToAnnotationSet(void);
					// downcast function
	virtual const AnnotationSet &CastToAnnotationSet(void) const;
					// downcast function
	
	friend istream &operator>>(istream&, AnnotationSet&);
};


// the following are related functions
ostream &operator<<(ostream &, const AnnotationSet&);
istream &operator>>(istream&, AnnotationSet&);
#endif
