//
//
// Module Name:		cmcAttribute.h
//
// CSCI/CSC/CSU:	CMC/Attribute
//
// Author:		Ken Kolda
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	.h for Attribute.  An Attribute is a name-value pair that describes
//	something about an AttributedObject.
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           11/17/95    kolda    Initial version
//

#ifndef _cmcAttribute_h
#define _cmcAttribute_h

class Attribute;                        // Incomplete Declaration

#include <iostream.h>			// For input streams

#include "cmcAttributeValue.h"		// For value of the Attribute
#include "cmcDocMgrObject.h"		// Has a base class of this

// An Attribute is a name-value pair describing some charateristic
// of an object
class Attribute : public DocumentManagerObject
{
  private:
	char *Name;			// Name of the attribute
	AttributeValue *pValue;		// Value of the attribute
	
  public:
	// TIPSTER functions
	Attribute(const char*, const AttributeValue&);
					// Constructor
	~Attribute(void);		// Destructor
	const char *GetName(void) const;
					// Returns Name component
	AttributeValue &GetValue(void) const;
					// Returns the Value component

	// TIPSTER additions
	static const char *ClassLabel;	// The name of this class

	Attribute(istream&);		// Constructor from buffer
	void WriteToStream(ostream &Buffer) const;  
					// Write value to a buffer
	Attribute *Copy(void) const;	// copy this
	int IsChanged(void) const;	// has this changed?
	void ClearChanged(void);	// clear Changed status
	virtual Attribute &CastToAttribute(void);
					// downcast function
	virtual const Attribute &CastToAttribute(void) const;
					// downcast function
	virtual const char *GetClass(void) const;
					// Get the class of this
};


// The following are I/O functions used 
ostream &operator<<(ostream &, Attribute &);
#endif
