//
//
// Module Name:		cmcAttributeReference.h
//
// CSCI/CSC/CSU:	CMC/AttributeReference
//
// Author:		Ken Kolda
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	.h file for AttributeReferences.  An AttributeReference is a
//	reference to a specific Attribute.
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           12/15/95    kolda    Initial version
//

#ifndef _cmcAttributeReference_h
#define _cmcAttributeReference_h

#include <iostream.h>

#include "cmcObjectReference.h"		// base class of this
#include "cmcAttributeValueType.h"	// a return value for TypeOf()
#include "cmcDocument.h"		// used in a constructor
#include "cmcDocMgrObject.h"		// Has a base class of this

// Provides an Attribute that is a reference to a CMC Attribute
#ifndef __GNUG__
class AttributeReference : public ObjectReference, public DocumentManagerObject
#else
class AttributeReference : public ObjectReference
#endif
{
  private:
	char *CollectionName;		// The Collection that owns the 
					// attribute
	char *DocumentId;		// ID of the Document that owns 
					// attribute
	char *AttributeName;		// Name of Referenced Attribute
	
	virtual void Write(ostream &Output) const;
					// write to output
	void Cleanup(void);		// cleanup allocated memory

  public:
	// TIPSTER functions
	AttributeReference(Document &ReferencedDocument, const char *Name);
					// Constructor
	~AttributeReference(void);	// Destructor
	const char *GetCollectionName(void) const;
					// Returns CollectionName component
	const char *GetDocumentId(void) const;
					// Returns the DocumentId component
	const char *GetAttributeName(void) const;
					// Returns the AttributeName component

	// TIPSTER additions
	static const char *ClassLabel;	// The name of this class

	AttributeReference(const char *NewCollectionName, 
			const char *NewDocumentId,
			const char *NewAttributeName);
					// construct from pieces
	AttributeReference(istream &Input);
					// read from input
	AttributeValueType TypeOf(void) const;
					// Returns "AttributeReference"
	virtual ObjectReference *Copy(void) const;
					// produce a copy of this
	virtual int operator==(const ObjectReference&) const;               
				       // test equality 
	virtual AttributeReference &CastToAttributeReference(void);
					// downcast function
	virtual const AttributeReference &CastToAttributeReference(void) const;
					// downcast function
	virtual const char *GetClass(void) const;
					// Get the class of this
};

#endif
