//
// Module Name:		cmcAttributeValue.h
//
// CSCI/CSC/CSU:	CMC/AttributeValue
//
// Author:		Ken Kolda
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	Provide the class definition for AttributeValue.  AttributeValue
//	is a virtual class: there is no corresponding .cc file to this.
//	An AttributeValue is the value of an Attribute.
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//	    11/14/1995	kolda	 Initial version
//

#ifndef _cmcAttributeValue_h
#define _cmcAttributeValue_h

#include <iostream.h>			// for input streams

#include "cmcAttributeValueType.h"	// Keeps types of AttributeValues
#include "cmcDocMgrObject.h"		// Has a base class of this

// the following are the known subclasses of this
class StringValue;
class SequenceValue;
class ObjectReferenceValue;

// Abstract class for the various Attribute Value Classes
class AttributeValue : public DocumentManagerObject
{
    public:
	// TIPSTER functions
	virtual ~AttributeValue(void) {}// Virtual Destructor for this
	virtual AttributeValueType TypeOf(void) const = 0;
					// Returns the type of the attribute 
					// value

	// TIPSTER additions
	static const char *ClassLabel;	// label for this class

	virtual AttributeValue *Copy(void) const = 0;
					// copy the AttributeValue
	virtual void WriteToStream(ostream &) const = 0;
					// Output the AttributeValue to a buffer
	virtual int operator==(const AttributeValue&) const = 0;
					// test equality
	virtual int operator!=(const AttributeValue&) const;
					// test non-equality
	virtual int IsChanged(void) const;
					// test if it has changed
	virtual void ClearChanged(void);
					// clear changed status

	virtual AttributeValue &CastToAttributeValue(void);
					// downcast operator
	virtual const AttributeValue &CastToAttributeValue(void) const;
					// downcast operator

	virtual SequenceValue &CastToSequenceValue(void);
					// downcast operator
	virtual const SequenceValue &CastToSequenceValue(void) const;
					// downcast operator
	virtual StringValue &CastToStringValue(void);
					// downcast operator
	virtual const StringValue &CastToStringValue(void) const;
					// downcast operator
	virtual ObjectReferenceValue &CastToObjectReferenceValue(void);
					// downcast operator
	virtual const ObjectReferenceValue &CastToObjectReferenceValue(void) 
						const;
					// downcast operator
};


// The following are non-member functions associated with AttributeValue
AttributeValue *ReadAttributeValue(istream &);		// Read AttributeValue 
							//  from buffer
ostream &operator<<(ostream &, const AttributeValue &);

#endif
