//
// Module Name:		cmcAttributeValueType.cc
//
// CSCI/CSC/CSU:	CMC/AttributeValueType
//
// Author:		Joe Dzikiewicz
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//			RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	This contains functions related to AttributeValueType.  An
//	AttributeValueType is an enumerated value that specifies the
//	type of an AttributeValue.
//
// Function List:
//	operator<< - Output an AttributeValueType
//	operator>> - Input an AttributeValueType
//
// Other Modules Called:
//	Error - Used for exceptions
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           11/17/95    jd_2     Initial version
//

#include <iostream.h>			// for I/O

#include "cmcAttributeValueType.h"	// declarations for this
#include "cmcError.h"			// for exception classes

//
// Function Name:	operator<<
//
// CSCI/CSC/CSU:	CMC/AttributeValueType
//
// Description:		Output an AttributeValueType with a C++ format
//			output function.
//
// Parameters:		Output - stream to output to
//			Type - value to output
//
// Return Value:	The Output stream
//
ostream &operator<<(ostream &Output, AttributeValueType Type)
{
    switch(Type)
    {
	case STRING:
	    Output << 's';
	    break;
	case SEQUENCE:
	    Output << 'S';
	    break;
	case COLLECTION_REFERENCE:
	    Output << 'C';
	    break;
	case DOCUMENT_REFERENCE:
	    Output << 'D';
	    break;
	case ANNOTATION_REFERENCE:
	    Output << 'A';
	    break;
	case ATTRIBUTE_REFERENCE:
	    Output << 'a';
	    break;
	default:
	    throw LogiconErrors::Parameter(
			"operator<<(ostream&, AttributeValueType)");
	    break;
    }

    return Output;
}



//
// Function Name:	operator>>
//
// CSCI/CSC/CSU:	CMC/AttributeValueType
//
// Description:		Input an AttributeValueType with a C++ format
//			input function.
//
// Parameters:		input - stream to input from
//			Type - place to put input value
//
// Return Value:	The input stream
//
istream &operator>>(istream &Input, AttributeValueType &Type)
{
    char ch;		// the next character

    // get the input
    Input >> ch;

    // if read failed...
    if(!Input)
	throw LogiconErrors::Read("operator>>(istream&, AttributeValueType&)");

    // determine what it is
    switch(ch)
    {
	case 's':
	    Type = STRING;
	    break;
	case 'S':
	    Type = SEQUENCE;
	    break;
	case 'C':
	    Type = COLLECTION_REFERENCE;
	    break;
	case 'D':
	    Type = DOCUMENT_REFERENCE;
	    break;
	case 'A':
	    Type = ANNOTATION_REFERENCE;
	    break;
	case 'a':
	    Type = ATTRIBUTE_REFERENCE;
	    break;
	default:
	    throw LogiconErrors::Format(
			"operator>>(istream&, AttributeValueType)");
	    break;
    }

    return(Input);
}
