//
//
// Module Name:		cmcAttributedObject.h
//
// CSCI/CSC/CSU:	CMC/AttributedObject
//
// Author:		Ken Kolda
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	.h for AttributedObject.  An AttributedObject is a virtual
//	base class representing objects that have Attributes.
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           11/17/95    kolda    Initial version
//

#ifndef _cmcAttributedObject_h
#define _cmcAttributedObject_h

#include "cmcSet.h"		// Attributes are kept in Sets
#include "cmcAttribute.h"	// AttributedObjects have Attributes
#include "cmcAttributeValue.h"	// in getting Attribute, its value is passed in
#include "cmcDocMgrObject.h"	// Has a base class of this

// AttributedObject is an abstract class for any object with attributes
class AttributedObject : public DocumentManagerObject
{
  private:
	Set<Attribute> Attributes;	// The set of attributes for this 
	  				// object
	int Changed;			// Changed flag for this

  public:
	// TIPSTER functions
	virtual ~AttributedObject(void);// Destructor
	virtual void PutAttribute(const char *Name, 
				  const AttributeValue &Value);
					// Adds the attribute with the given 
					// name and value to the object
	virtual const AttributeValue *GetAttribute(const char *Name) const;
					// Returns the value of the attribute
					// with the given name
	virtual Set<Attribute> &GetAttributes(void);
					// Returns the entire set of attributes
	virtual const Set<Attribute> &GetAttributes(void) const;
					// get Attributes in a constant way	

	// TIPSTER additions
	static const char *ClassLabel;	// label of this

	AttributedObject(void);		// Constructor
	AttributedObject(const Set<Attribute> &BaseAttributes);
					// Construct with given attributes

	virtual int HasAttributes(Set<Attribute> &) const;
					// test if the object has the given
					// attributes
	virtual int IsAttributesChanged(void) const;
					// test if any of the attributes have
					//	changed
	virtual void ClearAttributesChanged(void);
					// clear the AttributesChanged flag
	
	virtual const char *GetClass(void) const;
					// get name of this class
	virtual AttributedObject &CastToAttributedObject(void);
					// downcast function
	virtual const AttributedObject &CastToAttributedObject(void) const;
					// downcast function
};

#endif
