//
// Module Name:		cmcByteSequence.h
//
// CSCI/CSC/CSU:	CMC/ByeSequence
//
// Author:		Ken Kolda
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	Provide the class definition for ByteSequence.  A ByteSequence
//	is a collection of text.
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           11/14/95    kolda   Initial version
//

#ifndef _cmcByteSequence_h
#define _cmcByteSequence_h

#include <iostream.h>			// to allow I/O of ByteSequences

#include "cmcDocMgrObject.h"		// Has a base class of this

// ByteSequence is merely a string of raw document text
class ByteSequence : public DocumentManagerObject
{
  private:
	char *Text;			// The text of the byte sequence
	int TextLength;			// The length of the Text
	
  public:
	// TIPSTER functions
	ByteSequence(const char *NewText, int NewLength = -1);
					// Constructor
	~ByteSequence(void);		// Destructor
	int Length(void) const;		// Returns TextLength component
	const char *ConvertToString(void) const;
					// Returns the Text component

	// TIPSTER additions
	static const char *ClassLabel;	// The name of this class

	ByteSequence(istream &);	// construct by reading from stream
	ByteSequence *Copy(void) const;	// copy this
	void WriteToStream(ostream&) const;
					// write this to an output stream
	virtual ByteSequence &CastToByteSequence(void);
					// downcast function
	virtual const ByteSequence &CastToByteSequence(void) const;
					// downcast function
	virtual const char *GetClass(void) const;
					// Get the class of this
};


// the following are related functions
ostream &operator<<(ostream&, const ByteSequence&);

#endif
