//
// Module Name:		cmcCBinding.h
//
// CSCI/CSC/CSU:	CMC/CBinding
//
// Author:		Joe Dzikiewicz
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	The .h file for the CBinding module.  The CBinding module contains
//	all of the calls for the C binding of the CMC Document manager.
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           12/15/95    jd_2     Initial version
//

#ifndef _cmcCBinding_h
#define _cmcCBinding_h

#include "cmcAnnotation.h" 		// One object accessed by this
#include "cmcAnnotationReference.h" 	// One object accessed by this
#include "cmcAnnotationSet.h" 		// One object accessed by this
#include "cmcAttribute.h" 		// One object accessed by this
#include "cmcAttributeReference.h" 	// One object accessed by this
#include "cmcAttributeValue.h" 		// One object accessed by this
#include "cmcAttributeValueType.h" 	// One object accessed by this
#include "cmcAttributedObject.h" 	// One object accessed by this
#include "cmcByteSequence.h" 		// One object accessed by this
#include "cmcCollection.h" 		// One object accessed by this
#include "cmcCollectionReference.h" 	// One object accessed by this
#include "cmcDetectionNeed.h" 		// One object accessed by this
#include "cmcDetectionNeedCollection.h"	// One object accessed by this
#include "cmcDetectionQuery.h" 		// One object accessed by this
#include "cmcDocMgrObject.h" 		// One object accessed by this
#include "cmcDocument.h" 		// One object accessed by this
#include "cmcDocumentReference.h" 	// One object accessed by this
#include "cmcObjectReference.h" 	// One object accessed by this
#include "cmcObjectReferenceVal.h" 	// One object accessed by this
#include "cmcPersistentObject.h" 	// One object accessed by this
#include "cmcSequenceValue.h" 		// One object accessed by this
#include "cmcSet.h" 			// One object accessed by this
#include "cmcSpan.h" 			// One object accessed by this
#include "cmcStringValue.h" 		// One object accessed by this
#include "cmcTipsterCSet.h" 		// One object accessed by this

extern "C" {

/* Tipster Architecture header file (tipster.h) */
typedef char* tip_string;
typedef int tip_integer;

typedef DocumentManagerObject* tip_DocumentManagerObject;

typedef tip_DocumentManagerObject tip_Annotation;
typedef tip_DocumentManagerObject tip_AnnotationReference;
typedef tip_DocumentManagerObject tip_AnnotationSet;
typedef tip_DocumentManagerObject tip_Attribute;
typedef tip_DocumentManagerObject tip_AttributeReference;
typedef AttributeValueType tip_AttributeValueType;
typedef tip_DocumentManagerObject tip_AttributedObject;
typedef TipsterCSet *tip_AttributeSet;
typedef tip_DocumentManagerObject tip_AttributeValue;
typedef TipsterCSet *tip_AttributeValueSet;
typedef tip_DocumentManagerObject tip_ByteSequence;
// typedef tip_DocumentManagerObject tip_Collection;
typedef Collection *tip_Collection;
typedef tip_DocumentManagerObject tip_CollectionReference;
typedef tip_DocumentManagerObject tip_Document;
typedef tip_DocumentManagerObject tip_DetectionNeed;
//typedef tip_DocumentManagerObject tip_DetectionNeedCollection;
typedef Collection *tip_DetectionNeedCollection;
typedef tip_DocumentManagerObject tip_DetectionQuery;
typedef TipsterCSet *tip_DocumentCollectionIndexSet;
typedef tip_DocumentManagerObject tip_DocumentReference;
typedef tip_DocumentManagerObject tip_PersistentObject;
typedef TipsterCSet *tip_QueryCollectionIndexSet;
typedef tip_DocumentManagerObject tip_Span;
typedef TipsterCSet *tip_SpanSet;
typedef TipsterCSet *tip_stringSet;
typedef tip_DocumentManagerObject tip_Set;
typedef tip_DocumentManagerObject tip_ObjectReference;

void tip_Free(tip_DocumentManagerObject O);

tip_string tip_AddAnnotation(tip_Document, tip_Annotation);

void tip_Annotate(tip_Document, tip_string);

void tip_AnnotateCollection(tip_Collection, tip_Collection,
tip_string);

/* Type of argument 1 of AnnotationsAt can be  tip_Document or
tip_AnnotationSet  */
tip_AnnotationSet tip_AnnotationsAt(tip_DocumentManagerObject, tip_integer);

void tip_Close(tip_PersistentObject);

tip_string tip_ConvertToString(tip_ByteSequence);

tip_Document tip_CopyBareDocument(tip_Collection, tip_Document);

tip_Document tip_CopyDocument(tip_Collection, tip_Document);

tip_Annotation tip_CreateAnnotation(tip_string, tip_SpanSet,
tip_AttributeSet);

tip_AnnotationReference tip_CreateAnnotationReference(tip_Document,
tip_Annotation);

tip_AnnotationSet tip_CreateAnnotationSet(void);

tip_Attribute tip_CreateAttribute(tip_string, tip_AttributeValue);

tip_AttributeReference tip_CreateAttributeReference(tip_Document,
tip_string);

tip_AttributeSet tip_CreateAttributeSet(void);

tip_AttributeValueSet tip_CreateAttributeValueSet(void);

tip_ByteSequence tip_CreateByteSequence(tip_string);

tip_ByteSequence tip_CreateBinaryByteSequence(tip_string, tip_integer);

tip_Collection tip_CreateCollection(tip_string, tip_AttributeSet);

tip_CollectionReference tip_CreateCollectionReference(tip_Collection);

tip_DetectionNeed tip_CreateDetectionNeed(tip_Collection, tip_string,
		tip_ByteSequence, tip_AnnotationSet, tip_AttributeSet);

tip_DetectionNeedCollection tip_CreateDetectionNeedCollection(tip_string,
			tip_AttributeSet);

tip_DetectionQuery tip_CreateDetectionQuery(tip_Collection, tip_string,
		tip_ByteSequence, tip_AnnotationSet, tip_AttributeSet,
		tip_DetectionNeed);

tip_DocumentReference tip_GetDetectionNeed(tip_DetectionQuery);

void tip_SetDetectionNeed(tip_DetectionQuery, tip_DocumentReference);

tip_Document tip_CreateDocument(tip_Collection, tip_string,
		tip_ByteSequence, tip_AnnotationSet, tip_AttributeSet);

tip_DocumentCollectionIndexSet tip_CreateDocumentCollectionIndexSet();

tip_DocumentReference tip_CreateDocumentReference(tip_Document);

tip_DocumentReference tip_CreateDocumentReferenceFromSpecification(tip_string,
		tip_string);

tip_QueryCollectionIndexSet tip_CreateQueryCollectionIndexSet();

tip_Span tip_CreateSpan(tip_integer, tip_integer);

tip_SpanSet tip_CreateSpanSet(void);

tip_Collection tip_CreateVolatileCollection(tip_AttributeSet);

tip_Collection tip_CreateVolatileDetectionNeedCollection(tip_AttributeSet);

tip_stringSet tip_CreatestringSet(void);

/* Type of argument 1 of DeleteAnnotations can be  tip_Document or
tip_AnnotationSet  */
/* Type of argument 2 of DeleteAnnotations can be  tip_string or NULL
*/
void tip_DeleteAnnotations(tip_DocumentManagerObject, tip_string, 
		tip_AttributeSet);

void tip_DestroyCollection(tip_string);

/* Result of FirstDocument can be  tip_Document or NULL  */
tip_Document tip_FirstDocument(tip_Collection);

/* Type of argument 1 of GetAnnotation can be  tip_Document or
tip_AnnotationSet  */
tip_Annotation tip_GetAnnotation(tip_DocumentManagerObject, tip_string);

tip_string tip_GetAnnotationId(tip_AnnotationReference);

tip_AnnotationSet tip_GetAnnotations(tip_Document);

tip_AttributeValue tip_GetAttribute(tip_AttributedObject, tip_string);

tip_string tip_GetAttributeName(tip_AttributeReference);

tip_AttributeSet tip_GetAttributes(tip_AttributedObject);

/* Result of GetByExternalId can be  tip_Document or NULL  */
tip_Document tip_GetByExternalId(tip_Collection, tip_string);

/* Type of argument 1 of GetCollectionName can be
tip_AnnotationReference or tip_AttributeReference or
tip_DocumentReference or tip_CollectionReference  */
tip_string tip_GetCollectionName(tip_DocumentManagerObject);

/* Result of GetDocument can be  tip_Document or NULL  */
tip_Document tip_GetDocument(tip_Collection, tip_string);

/* Type of argument 1 of GetDocumentId can be  tip_DocumentReference or
tip_AnnotationReference or tip_AttributeReference  */
tip_string tip_GetDocumentId(tip_DocumentManagerObject);

tip_integer tip_GetEnd(tip_Span);

tip_string tip_GetExternalId(tip_Document);

/* Type of argument 1 of GetId can be  tip_Annotation or tip_Document
*/
tip_string tip_GetId(tip_DocumentManagerObject);

tip_string tip_GetName(tip_PersistentObject);

tip_string tip_GetOwner(tip_Collection);

tip_Collection tip_GetParent(tip_Document);

tip_ByteSequence tip_GetRawData(tip_Document);

tip_SpanSet tip_GetSpans(tip_Annotation);

tip_integer tip_GetStart(tip_Span);

tip_string tip_GetType(tip_Annotation);

void *tip_GetValue(tip_DocumentManagerObject);

tip_integer tip_Length(tip_DocumentManagerObject);

tip_AnnotationSet tip_MergeAnnotations(tip_AnnotationSet,
tip_AnnotationSet);

/* Type of argument 1 of NextAnnotations can be  tip_Document or
tip_AnnotationSet  */
tip_AnnotationSet tip_NextAnnotations(tip_DocumentManagerObject, tip_integer);

/* Result of NextDocument can be  tip_Document or NULL  */
tip_Document tip_NextDocument(tip_Collection);

void *tip_Nth(tip_Set, tip_integer);

tip_Collection tip_OpenCollection(tip_string);

void *tip_Pop(tip_Set);

void tip_Push(tip_Set, void *);

void tip_PutAttribute(tip_AttributedObject, tip_string, tip_AttributeValue);

tip_Document tip_ReadSGML(tip_string, tip_Collection, tip_string);

/* Type of argument 1 of RemoveAnnotation can be  tip_Document or
tip_AnnotationSet  */
void tip_RemoveAnnotation(tip_DocumentManagerObject, tip_string);

void tip_RemoveDocument(tip_Collection, tip_string);

/* Type of argument 1 of SelectAnnotations can be  tip_Document or
tip_AnnotationSet  */
/* Type of argument 2 of SelectAnnotations can be  tip_string or NULL
*/
tip_AnnotationSet tip_SelectAnnotations(tip_DocumentManagerObject, tip_string,
tip_AttributeSet);

void tip_SetExternalId(tip_Document, tip_string);

void tip_SetOwner(tip_Collection, tip_string);

void tip_Sync(tip_PersistentObject);

tip_AttributeValueType tip_TypeOf(tip_AttributeValue);

tip_string tip_WriteSGML(tip_Document, tip_AnnotationSet,
tip_stringSet);


tip_string tip_GetClass(tip_DocumentManagerObject);

tip_AttributeValue tip_CreateStringValue(tip_string);

tip_AttributeValue tip_CreateSequenceValue(tip_AttributeValueSet);

tip_AttributeValue tip_CreateObjectReferenceValue(tip_ObjectReference);

}
#endif
