//
// Module Name:		cmcCollection.h
//
// CSCI/CSC/CSU:	CMC/Collection
//
// Author:		Ken Kolda
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	Class definition for the Collection class.  A Collection is a
//	virtual class that represents the types of Document Collections.
//	A Document Collection stores documents and references to documents.
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           11/28/95    kolda    Initial version
//

#ifndef _cmcCollection_h
#define _cmcCollection_h

class Collection;

#include "cmcPersistentObject.h"	// Collection is a PersistentObject
#include "cmcAttributedObject.h"	// Collection is an AttributedObject
#include "cmcSet.h"			// Collection uses Sets in input parms
#include "cmcDocument.h"		// Collection uses Documents
#include "cmcDocMgrObject.h"		// Has a base class of this

// Collection provides an abstract class for Volatile and Persistent 
// Collections

#ifndef __GNUG__
class Collection : public PersistentObject, public AttributedObject, public DocumentManagerObject
#else
class Collection : public PersistentObject, public AttributedObject
#endif
{
  private:
	char* Owner;		// The owner of the collection

  public:
	// TIPSTER functions
	Collection(const char *NewName);
				// constructor for OpenCollection
	Collection(const char *NewName, const Set<Attribute> &NewAttributes);
				// Constructor for CreateCollection()
	Collection(const Set<Attribute> &NewAttributes);
				// Constructor for CreateVolatileCollection()
	virtual ~Collection(void);	
				// Virtual Destructor
	virtual int Length(void) const = 0;	
				// Number of Documents in the Collection
	virtual void RemoveDocument(const char *Id) = 0;
				// Removes document from Collection
	virtual Document *GetDocument(const char *Id) = 0;
				// Retrieves a Document from a Collection
	virtual Document *FirstDocument(void) = 0;
				// Retieves first Document in Collection
	virtual Document *NextDocument(void) = 0;
				// Retrieves next Document in Collection
	virtual Document *GetByExternalId(const char *ExternalId) = 0;
				// Retrieves Document with given External ID
	virtual void AnnotateCollection(Collection &Which, 
			const char *AnnotatorName) = 0;
				// Annotates Documents in Collection
	virtual void Sync(void) = 0;
				// Flushes changes to the Collection
	void SetOwner(const char *NewOwner);
				// Sets the Owner component
	const char *GetOwner(void) const;
				// Returns the Owner component

	// TIPSTER additions
	static const char *ClassLabel;	// The name of this class

	Collection(void);	// construct with nothing
	virtual void Store(Document &NewDocument) = 0;
				// Stores the Document in the Collection
	virtual void Update(Document &NewDocument) = 0;
				// Updates the Document in Collection
	virtual const char *GetClass(void) const;
				// Get the class of this
	virtual Collection &CastToCollection(void);
				// downcast function
	virtual const Collection &CastToCollection(void) const;
				// downcast function
	virtual AttributedObject &CastToAttributedObject(void);
				// downcast function
	virtual const AttributedObject &CastToAttributedObject(void) const;
				// downcast function
};

#endif
