//
// Module Name:		cmcCollectionReference
//
// CSCI/CSC/CSU:	CMC/CollectionReference
//
// Author:		Ken Kolda
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	This is the .h for CollectionReference.  A CollectionReference is 
//	a reference to a specific Collection.
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           12/15/95    kolda    Initial version
//

#ifndef _cmcCollectionReference_h
#define _cmcCollectionReference_h

#include <iostream.h>			// to get IO streams

#include "cmcObjectReference.h"		// has base class for this
#include "cmcAttributeValueType.h"	// type of ObjectReference that this is
#include "cmcCollection.h"		// for a constructor
#include "cmcDocMgrObject.h"		// Has a base class of this

// Provides an Attribute that is a reference to a CMC Coolection
#ifndef __GNUG__
class CollectionReference : public ObjectReference, public DocumentManagerObject
#else
class CollectionReference : public ObjectReference
#endif
{
  private:
	char* CollectionName;		// The Name of the Collection

	virtual void Write(ostream &Output) const;
					// write to output

  public:
	// TIPSTER functions
	CollectionReference(Collection &ReferencedCollection);
					// Constructor
	~CollectionReference(void);	// Destructor
	const char *GetCollectionName(void) const;
					// Returns CollectionName component

	// TIPSTER additions
	static const char *ClassLabel;	// The name of this class
	
	CollectionReference(const char *NewCollectionId);
					// constructor
	CollectionReference(istream &Input);
					// construct from input
	AttributeValueType TypeOf(void) const;
					// Returns "CollectionReference"
	virtual ObjectReference *Copy(void) const;
	 				// produce a copy of this
	virtual int operator==(const ObjectReference&) const; 
				       // test equality 

	virtual CollectionReference &CastToCollectionReference(void);
					// downcast function
	virtual const CollectionReference &CastToCollectionReference(void) 
				const;
					// downcast function
	virtual const char *GetClass(void) const;
					// Get the class of this
};

#endif
