//
//
// Module Name:         cmcDetectionNeed.cc - The PRIDES representation of a
//                             Tipster Detection Need
//
// CSCI/CSC/CSU:        CMC/DetectionNeed
//
// Author:		Kenneth Kolda
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//			RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:  DetectionNeed is a derived class from the CMC class
//               Document which holds a system- and collection-
//               independent query.
//
// Function List:
//   DetectionNeed(Collection&, char*, ByteSequence*, AnnotationSet&,
//            Set<Attribute>&) - Contructor (as for a Document)
//   DetectionNeed(DetectionNeed&) - Copy Constructor
//   DetectionNeed(Document&) - Copy Constructor (as for a Document)
//   CopyBare(Collection&) - Copy a bare document
//   CopyDocument(Collection&) - Copy a complete document
// + DetectionQuery* QueryGenerator() - Generates a DetectionQuery for
//            this DetectionNeed
//   DetectionQuery &CastToDetectionQuery() - Downcast function, in two flavors
//
// + = caller responsible for destructing return value
//
// Other Modules Called:
//
//
///////////////////////////////////////////////////////////////////////////////
//
// Maintenance History
// Version     Date      Userid     Description of Changes
//=============================================================================
// 1.0         12/05/95  kolda      Initial version
//
///////////////////////////////////////////////////////////////////////////////

#include "cmcDocument.h"
#include "cmcDetectionNeed.h"




const char *DetectionNeed::ClassLabel = "DetectionNeed";	
							// name of the class



//////////////////////////////////////////////////////////////////////////////
//
// Function Name:  DetectionNeed
//
// Description:    Constructor
//
// CSCI/CSC/CSU:   CMC/DetectionNeed
//
// Parameters:     Collection &NewParent - Parent Collection for this Need
//                 char* NewExternalId - External ID for this Need
//                 ByteSequence* NewRawData - The Actual text of the Need
//                 AnnotationSet &NewAnnotations - Annotation for the Need
//                 Set<Attribute> &NewAttributes - Attributes of the Need
//
// Return Value:   None
//
// Caller Destructs Return Value:  N/A
//
//////////////////////////////////////////////////////////////////////////////

DetectionNeed::DetectionNeed(Collection& NewParent, const char* NewExternalId,
			     const ByteSequence* NewRawData, 
			     AnnotationSet& NewAnnotations,
			     Set<Attribute>& NewAttributes) :
			     Document(NewParent, NewExternalId, NewRawData,
				      NewAnnotations, NewAttributes)
{
}



//////////////////////////////////////////////////////////////////////////////
//
// Function Name:  DetectionNeed
//
// Description:    Constructor
//
// CSCI/CSC/CSU:   CMC/DetectionNeed
//
// Parameters:     Collection* NewParent - Parent Collection for Need
//                 Document* Doc - Base Document of Need
//
// Return Value:   None
//
// Caller Destructs Return Value:  N/A
//
//////////////////////////////////////////////////////////////////////////////

DetectionNeed::DetectionNeed(const DetectionNeed& Base) : Document(Base)
{
}



//////////////////////////////////////////////////////////////////////////////
//
// Function Name:  DetectionNeed
//
// Description:    Constructor
//
// CSCI/CSC/CSU:   CMC/DetectionNeed
//
// Parameters:     Document* Doc - Base Document of Need
//
// Return Value:   None
//
// Caller Destructs Return Value:  N/A
//
//////////////////////////////////////////////////////////////////////////////

DetectionNeed::DetectionNeed(const Document& Base) : Document(Base)
{
}




//////////////////////////////////////////////////////////////////////////////
//
// Function Name:  QueryGenerator
//
// Description:    Creates the DetectionQuery that corresponds to this 
//                 DetectionNeed
//
// CSCI/CSC/CSU:   CMC/DetectionNeed
//
// Parameters:     None
//
// Return Value:   None
//
// Caller Destructs Return Value:  Yes
//
//////////////////////////////////////////////////////////////////////////////

DetectionQuery* DetectionNeed::QueryGenerator(void)
{
   // For now, just duplicate the Detection Need
   DetectionQuery* DQ = new DetectionQuery(GetParent(), GetExternalId(),
			GetRawData(), GetAnnotations(), GetAttributes(), *this);
   return DQ;
   
   //  This is TBD, but will probably look like:
   //
   //  // First Get the Doc form of the Detection Query
   //  Document* Doc = (Document*) ::QueryGenerator(this);
   // 
   //  // Now convert to DetectionQuery object
   //  if (Doc != NULL)
   //  {
   //     DetectionQuery* DQ = new DetectionQuery(*Doc, *this);
   //     return DQ;
   //  }
   //  else
   //        throw SecError::SearchEngineError(
   //                    "DetectionNeed::QueryGenerator()");
   //
}



//
// Function Name:	DetectionNeed::CopyBare(Collection&)
//
// CSCI/CSC/CSU:	CMC/DetectionNeed
//
// Description:		Create a copy of the DetectionNeed without any
//			Annotations or Attributes.
//
// Parameters:		NewParent - Place to put the new copy
//
// Return Value:	The new DetectionNeed
//
Document *DetectionNeed::CopyBare(Collection &NewParent)
{
    AnnotationSet NewAnnotations;		// annotations on new item
    Set<Attribute> NewAttributes;		// attribute set on new item

    return new DetectionNeed(NewParent, GetExternalId(),
	GetRawData(), NewAnnotations, NewAttributes);
}



//
// Function Name:	DetectionNeed::CopyDocument(Collection&)
//
// CSCI/CSC/CSU:	CMC/DetectionNeed
//
// Description:		Create a copy of the DetectionNeed with all
//			Annotations and Attributes.
//
// Parameters:		NewParent - Place to put the new copy
//
// Return Value:	The new DetectionNeed
//
Document *DetectionNeed::CopyDocument(Collection &NewParent)
{
    return new DetectionNeed(NewParent, GetExternalId(),
	GetRawData(), GetAnnotations(), GetAttributes());
}




//
// Function Name:	DetectionNeed::CastToDetectionNeed()
//
// CSCI/CSC/CSU:	CMC/DetectionNeed
//
// Description:		Downcast function.
//
// Parameters:		None
//
// Return Value:	*this
//
DetectionNeed &DetectionNeed::CastToDetectionNeed()
{
    return *this;
}






//
// Function Name:	DetectionNeed::CastToDetectionNeed()
//
// CSCI/CSC/CSU:	CMC/DetectionNeed
//
// Description:		Downcast function.
//
// Parameters:		None
//
// Return Value:	*this
//
const DetectionNeed &DetectionNeed::CastToDetectionNeed() const
{
    return *this;
}




