//
//
// Module Name:         cmcDetectionQuery.h
//
// CSCI/CSC/CSU:        CMC/DetectionQuery
//
// Author:		Kenneth Kolda
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//			RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:  
//      Provide class definitions for DetectionQuery.
//
//
///////////////////////////////////////////////////////////////////////////////
//
// Maintenance History
// Version     Date      Userid     Description of Changes
//=============================================================================
// 1.0         12/05/95  kolda      Initial version
//
///////////////////////////////////////////////////////////////////////////////

#ifndef _cmcDetectionQuery_h
#define _cmcDetectionQuery_h

class DetectionQuery;				// Incomplete Declaration

#include "cmcDocument.h"
#include "cmcDocumentReference.h"
#include "cmcSet.h"
#include "cmcByteSequence.h"
#include "cmcDetectionNeed.h"
#include "cmcDetectionNeedCollection.h"

// DetectionQuery is the Tipster system-specific respresentation of a query
class DetectionQuery : public Document
{
  private:
	DocumentReference SourceDetectionNeed;	// Detection Need that 
						// generated this query.

	void Cleanup(void);			// clean allocated data
	
  public:
	// the following are Tipster functions
	~DetectionQuery(void);			// Destructor
	const DocumentReference& GetDetectionNeed(void) const;
						// Returns SourceDetectionNeed
	virtual Document *CopyDocument(Collection &NewParent);
						// copy the DetectionQuery
	virtual Document *CopyBare(Collection &NewParent);
						// copy the DetectionQuery 
						//   without attributes, etc

	// the following are Tipster additions
	static const char *ClassLabel;		// The name of this class

	DetectionQuery(Document& Base); 	// Constructor
	DetectionQuery(Collection& NewParent, const char* NewExternalId,
			const ByteSequence* NewRawData,
			AnnotationSet& NewAnnotations,
			Set<Attribute>& NewAttributes,
			DetectionNeed &NewSourceDetectionNeed);
						// constructor
	DetectionQuery(Collection& NewParent, const char* NewExternalId,
			const ByteSequence* NewRawData,
			AnnotationSet& NewAnnotations,
			Set<Attribute>& NewAttributes,
			DocumentReference &NewSourceDetectionNeed);
						// constructor
	void SetDetectionNeed(DocumentReference &NewNeed);
						// set the DetectionNeed
	DetectionQuery(const DetectionQuery &Base);
						// copy constructor
	DetectionQuery &CastToDetectionQuery(void);
						// downcast function
	const DetectionQuery &CastToDetectionQuery(void) const;
						// downcast function
};

#endif

