//
// Module Name:		cmcDocMgrObject.cc
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Author:		Joe Dzikiewicz
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//			RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	Contains all code for DocumentManagerObjects.  DocumentManagerObject
//	is an abstract superclass for all classes representing TIPSTER
//	classes that are part of the Document Manager.  The primary
//	purpose of this is to allow all TIPSTER objects to have a
//	shared base class, allowing things like a shared virtual 
//	destructor, downcast functions, and a way to get the class
//	label of any TIPSTER object.
//
// Function List:
//	DocumentManagerObject::CastToX() - For all subclasses X of this, there
//		is a default CastToX() function that raises a type
//		mismatch exception.  Each subclass replaces this with a
//		function that performs the downcast.
//
// Other Modules Called:
//	All the subclasses, as return values to the downcast functions.
//	Error, which contains valid exceptions.
//
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           1/2/96      jd_2     Initial version
//

#include <stddef.h>			// for NULL

#include "cmcDocMgrObject.h"		// for declaration of this
#include "cmcError.h"			// for exception classes



//
// Function Name:	DocumentManagerObject::CastToAnnotation()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToAnnotation throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
Annotation &DocumentManagerObject::CastToAnnotation()
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToAnnotation(void)");

    // the  following is to satisfy the compiler
    return *(Annotation*)NULL;
}


//
// Function Name:	DocumentManagerObject::CastToAnnotation()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToAnnotation throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
const Annotation &DocumentManagerObject::CastToAnnotation() const
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToAnnotation(void)");

    // the  following is to satisfy the compiler
    return *(Annotation*)NULL;
}






//
// Function Name:	DocumentManagerObject::CastToAnnotationReference()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToAnnotationReference throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
AnnotationReference &DocumentManagerObject::CastToAnnotationReference()
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToAnnotationReference(void)");

    // the  following is to satisfy the compiler
    return *(AnnotationReference*)NULL;
}


//
// Function Name:	DocumentManagerObject::CastToAnnotationReference()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToAnnotationReference throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
const AnnotationReference &DocumentManagerObject::CastToAnnotationReference() 
			const
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToAnnotationReference(void)");

    // the  following is to satisfy the compiler
    return *(AnnotationReference*)NULL;
}



//
// Function Name:	DocumentManagerObject::CastToAnnotationSet()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToAnnotationSet throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
AnnotationSet &DocumentManagerObject::CastToAnnotationSet()
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToAnnotationSet(void)");

    // the  following is to satisfy the compiler
    return *(AnnotationSet*)NULL;
}


//
// Function Name:	DocumentManagerObject::CastToAnnotationSet()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToAnnotationSet throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
const AnnotationSet &DocumentManagerObject::CastToAnnotationSet() const
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToAnnotationSet(void)");

    // the  following is to satisfy the compiler
    return *(AnnotationSet*)NULL;
}



//
// Function Name:	DocumentManagerObject::CastToAttribute()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToAttribute throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
Attribute &DocumentManagerObject::CastToAttribute()
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToAttribute(void)");

    // the  following is to satisfy the compiler
    return *(Attribute*)NULL;
}


//
// Function Name:	DocumentManagerObject::CastToAttribute()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToAttribute throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
const Attribute &DocumentManagerObject::CastToAttribute() const
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToAttribute(void)");

    // the  following is to satisfy the compiler
    return *(Attribute*)NULL;
}



//
// Function Name:	DocumentManagerObject::CastToAttributeReference()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToAttributeReference throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
AttributeReference &DocumentManagerObject::CastToAttributeReference()
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToAttributeReference(void)");

    // the  following is to satisfy the compiler
    return *(AttributeReference*)NULL;
}


//
// Function Name:	DocumentManagerObject::CastToAttributeReference()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToAttributeReference throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
const AttributeReference &DocumentManagerObject::CastToAttributeReference() 
			const
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToAttributeReference(void)");

    // the  following is to satisfy the compiler
    return *(AttributeReference*)NULL;
}



//
// Function Name:	DocumentManagerObject::CastToAttributeValue()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToAttributeValue throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
AttributeValue &DocumentManagerObject::CastToAttributeValue()
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToAttributeValue(void)");

    // the  following is to satisfy the compiler
    return *(AttributeValue*)NULL;
}


//
// Function Name:	DocumentManagerObject::CastToAttributeValue()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToAttributeValue throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
const AttributeValue &DocumentManagerObject::CastToAttributeValue() const
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToAttributeValue(void)");

    // the  following is to satisfy the compiler
    return *(AttributeValue*)NULL;
}



//
// Function Name:	DocumentManagerObject::CastToAttributedObject()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToAttributedObject throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
AttributedObject &DocumentManagerObject::CastToAttributedObject()
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToAttributedObject(void)");

    // the  following is to satisfy the compiler
    return *(AttributedObject*)NULL;
}


//
// Function Name:	DocumentManagerObject::CastToAttributedObject()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToAttributedObject throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
const AttributedObject &DocumentManagerObject::CastToAttributedObject() const
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToAttributedObject(void)");

    // the  following is to satisfy the compiler
    return *(AttributedObject*)NULL;
}



//
// Function Name:	DocumentManagerObject::CastToByteSequence()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToByteSequence throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
ByteSequence &DocumentManagerObject::CastToByteSequence()
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToByteSequence(void)");

    // the  following is to satisfy the compiler
    return *(ByteSequence*)NULL;
}


//
// Function Name:	DocumentManagerObject::CastToByteSequence()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToByteSequence throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
const ByteSequence &DocumentManagerObject::CastToByteSequence() const
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToByteSequence(void)");

    // the  following is to satisfy the compiler
    return *(ByteSequence*)NULL;
}



//
// Function Name:	DocumentManagerObject::CastToCollection()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToCollection throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
Collection &DocumentManagerObject::CastToCollection()
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToCollection(void)");

    // the  following is to satisfy the compiler
    return *(Collection*)NULL;
}


//
// Function Name:	DocumentManagerObject::CastToCollection()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToCollection throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
const Collection &DocumentManagerObject::CastToCollection() const
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToCollection(void)");

    // the  following is to satisfy the compiler
    return *(Collection*)NULL;
}



//
// Function Name:	DocumentManagerObject::CastToCollectionReference()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToCollectionReference throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
CollectionReference &DocumentManagerObject::CastToCollectionReference()
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToCollectionReference(void)");

    // the  following is to satisfy the compiler
    return *(CollectionReference*)NULL;
}


//
// Function Name:	DocumentManagerObject::CastToCollectionReference()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToCollectionReference throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
const CollectionReference &DocumentManagerObject::CastToCollectionReference() 
			const
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToCollectionReference(void)");

    // the  following is to satisfy the compiler
    return *(CollectionReference*)NULL;
}



//
// Function Name:	DocumentManagerObject::CastToDocument()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToDocument throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
Document &DocumentManagerObject::CastToDocument()
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToDocument(void)");

    // the  following is to satisfy the compiler
    return *(Document*)NULL;
}


//
// Function Name:	DocumentManagerObject::CastToDocument()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToDocument throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
const Document &DocumentManagerObject::CastToDocument() const
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToDocument(void)");

    // the  following is to satisfy the compiler
    return *(Document*)NULL;
}




//
// Function Name:	DocumentManagerObject::CastToDetectionNeed()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToDetectionNeed throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
DetectionNeed &DocumentManagerObject::CastToDetectionNeed()
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToDetectionNeed(void)");

    // the  following is to satisfy the compiler
    return *(DetectionNeed*)NULL;
}





//
// Function Name:	DocumentManagerObject::CastToDetectionNeed()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToDetectionNeed throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
const DetectionNeed &DocumentManagerObject::CastToDetectionNeed() const
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToDetectionNeed(void)");

    // the  following is to satisfy the compiler
    return *(DetectionNeed*)NULL;
}



//
// Function Name:	DocumentManagerObject::CastToDetectionQuery()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToDetectionQuery throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
DetectionQuery &DocumentManagerObject::CastToDetectionQuery()
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToDetectionQuery(void)");

    // the  following is to satisfy the compiler
    return *(DetectionQuery*)NULL;
}





//
// Function Name:	DocumentManagerObject::CastToDetectionQuery()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToDetectionQuery throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
const DetectionQuery &DocumentManagerObject::CastToDetectionQuery() const
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToDetectionQuery(void)");

    // the  following is to satisfy the compiler
    return *(DetectionQuery*)NULL;
}




//
// Function Name:	DocumentManagerObject::CastToDocumentReference()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToDocumentReference throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
DocumentReference &DocumentManagerObject::CastToDocumentReference()
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToDocumentReference(void)");

    // the  following is to satisfy the compiler
    return *(DocumentReference*)NULL;
}


//
// Function Name:	DocumentManagerObject::CastToDocumentRefference()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToDocumentReference throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
const DocumentReference &DocumentManagerObject::CastToDocumentReference() const
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToDocumentReference(void)");

    // the  following is to satisfy the compiler
    return *(DocumentReference*)NULL;
}



//
// Function Name:	DocumentManagerObject::CastToObjectReference()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToObjectReference throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
ObjectReference &DocumentManagerObject::CastToObjectReference()
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToObjectReference(void)");

    // the  following is to satisfy the compiler
    return *(ObjectReference*)NULL;
}


//
// Function Name:	DocumentManagerObject::CastToObjectReference()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToObjectReference throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
const ObjectReference &DocumentManagerObject::CastToObjectReference() const
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToObjectReference(void)");

    // the  following is to satisfy the compiler
    return *(ObjectReference*)NULL;
}



//
// Function Name:	DocumentManagerObject::CastToObjectReferenceValue()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToObjectReferenceValue throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
ObjectReferenceValue &DocumentManagerObject::CastToObjectReferenceValue()
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToObjectReferenceValue(void)");

    // the  following is to satisfy the compiler
    return *(ObjectReferenceValue*)NULL;
}


//
// Function Name:	DocumentManagerObject::CastToObjectReferenceValue()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToObjectReferenceValue throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
const ObjectReferenceValue &DocumentManagerObject::CastToObjectReferenceValue()
		const
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToObjectReferenceValue(void)");

    // the  following is to satisfy the compiler
    return *(ObjectReferenceValue*)NULL;
}



//
// Function Name:	DocumentManagerObject::CastToPersistentObject()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToPersistentObject throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
PersistentObject &DocumentManagerObject::CastToPersistentObject()
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToPersistentObject(void)");

    // the  following is to satisfy the compiler
    return *(PersistentObject*)NULL;
}


//
// Function Name:	DocumentManagerObject::CastToPersistentObject()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToPersistentObject throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
const PersistentObject &DocumentManagerObject::CastToPersistentObject() const
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToPersistentObject(void)");

    // the  following is to satisfy the compiler
    return *(PersistentObject*)NULL;
}



//
// Function Name:	DocumentManagerObject::CastToSequenceValue()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToSequenceValue throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
SequenceValue &DocumentManagerObject::CastToSequenceValue()
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToSequenceValue(void)");

    // the  following is to satisfy the compiler
    return *(SequenceValue*)NULL;
}


//
// Function Name:	DocumentManagerObject::CastToSequenceValue()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToSequenceValue throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
const SequenceValue &DocumentManagerObject::CastToSequenceValue() const
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToSequenceValue(void)");

    // the  following is to satisfy the compiler
    return *(SequenceValue*)NULL;
}



//
// Function Name:	DocumentManagerObject::CastToSpan()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToSpan throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
Span &DocumentManagerObject::CastToSpan()
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToSpan(void)");

    // the  following is to satisfy the compiler
    return *(Span*)NULL;
}


//
// Function Name:	DocumentManagerObject::CastToSpan()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToSpan throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
const Span &DocumentManagerObject::CastToSpan() const
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToSpan(void)");

    // the  following is to satisfy the compiler
    return *(Span*)NULL;
}



//
// Function Name:	DocumentManagerObject::CastToStringValue()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToStringValue throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
StringValue &DocumentManagerObject::CastToStringValue()
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToStringValue(void)");

    // the  following is to satisfy the compiler
    return *(StringValue*)NULL;
}


//
// Function Name:	DocumentManagerObject::CastToStringValue()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToStringValue throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
const StringValue &DocumentManagerObject::CastToStringValue() const
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToStringValue(void)");

    // the  following is to satisfy the compiler
    return *(StringValue*)NULL;
}



//
// Function Name:	DocumentManagerObject::CastToTipsterCSet()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToTipsterCSet throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
TipsterCSet &DocumentManagerObject::CastToTipsterCSet()
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToTipsterCSet(void)");

    // the  following is to satisfy the compiler
    return *(TipsterCSet*)NULL;
}


//
// Function Name:	DocumentManagerObject::CastToTipsterCSet()
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Description:		Default CastToTipsterCSet throws exceptions.
//
// Parameters:		None
//
// Return Value:	Never returns normally
//
const TipsterCSet &DocumentManagerObject::CastToTipsterCSet() const
{
    throw LogiconErrors::InvalidType(
		"DocumentManagerObject::CastToTipsterCSet(void)");

    // the  following is to satisfy the compiler
    return *(TipsterCSet*)NULL;
}
