//
// Module Name:		cmcDocMgrObject.h
//
// CSCI/CSC/CSU:	CMC/DocumentManagerObject
//
// Author:		Joe Dzikiewicz
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	.h for DocumentManagerObject.  A DocumentManagerObject is the base
//	object for all objects that are visible parts of the CMC
//	Document manager.
//
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           12/15/95    jd_2     Initial version
//

#ifndef _cmcDocMgrObject_h
#define _cmcDocMgrObject_h

// the following are declarations to allow downcast functions
class Annotation;
class AnnotationReference;
class AnnotationSet;
class Attribute;
class AttributeReference;
class AttributeValue;
class AttributedObject;
class ByteSequence;
class Collection;
class CollectionReference;
class DetectionNeed;
class DetectionQuery;
class Document;
class DocumentReference;
class ObjectReference;
class ObjectReferenceValue;
class PersistentObject;
class SequenceValue;
class Span;
class StringValue;
class TipsterCSet;

class DocumentManagerObject
{
    public:
	virtual ~DocumentManagerObject(void){} 	// virtual destructor
	virtual const char *GetClass(void) const = 0;	
						// get the type of this

	// the following are all virtual downcast functions to downcast to the
	//	specified types
	virtual Annotation &CastToAnnotation(void);
	virtual const Annotation &CastToAnnotation(void) const;
	virtual AnnotationReference &CastToAnnotationReference(void);
	virtual const AnnotationReference &CastToAnnotationReference(void) 
					const;
	virtual AnnotationSet &CastToAnnotationSet(void);
	virtual const AnnotationSet &CastToAnnotationSet(void) const;
	virtual Attribute &CastToAttribute(void);
	virtual const Attribute &CastToAttribute(void) const;
	virtual AttributeReference &CastToAttributeReference(void);
	virtual const AttributeReference &CastToAttributeReference(void) const;
	virtual AttributeValue &CastToAttributeValue(void);
	virtual const AttributeValue &CastToAttributeValue(void) const;
	virtual AttributedObject &CastToAttributedObject(void);
	virtual const AttributedObject &CastToAttributedObject(void) const;
	virtual ByteSequence &CastToByteSequence(void);
	virtual const ByteSequence &CastToByteSequence(void) const;
	virtual Collection &CastToCollection(void);
	virtual const Collection &CastToCollection(void) const;
	virtual CollectionReference &CastToCollectionReference(void);
	virtual const CollectionReference &CastToCollectionReference(void) 
					const;
	virtual DetectionNeed &CastToDetectionNeed(void);
	virtual const DetectionNeed &CastToDetectionNeed(void) const;
	virtual DetectionQuery &CastToDetectionQuery(void);
	virtual const DetectionQuery &CastToDetectionQuery(void) const;
	virtual Document &CastToDocument(void);
	virtual const Document &CastToDocument(void) const;
	virtual DocumentReference &CastToDocumentReference(void);
	virtual const DocumentReference &CastToDocumentReference(void) const;
	virtual ObjectReference &CastToObjectReference(void);
	virtual const ObjectReference &CastToObjectReference(void) const;
	virtual ObjectReferenceValue &CastToObjectReferenceValue(void);
	virtual const ObjectReferenceValue &CastToObjectReferenceValue(void) 
					const;
	virtual PersistentObject &CastToPersistentObject(void);
	virtual const PersistentObject &CastToPersistentObject(void) const;
	virtual SequenceValue &CastToSequenceValue(void);
	virtual const SequenceValue &CastToSequenceValue(void) const;
	virtual Span &CastToSpan(void);
	virtual const Span &CastToSpan(void) const;
	virtual StringValue &CastToStringValue(void);
	virtual const StringValue &CastToStringValue(void) const;
	virtual TipsterCSet &CastToTipsterCSet(void);
	virtual const TipsterCSet &CastToTipsterCSet(void) const;
};

#endif
