//
//
// Module Name:		cmcDocument.h
//
// CSCI/CSC/CSU:	CMC/Document
//
// Author:		Ken Kolda
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	.h for Document.  A Document represents a quantum TIPSTER block of
//	text.
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           11/17/95    kolda    Initial version
//

#ifndef _cmcDocument_h
#define _cmcDocument_h

#include <iostream.h>			// to allow I/O of Documents

class Document;   // Incomplete definition

// #include "prides.h"			// General includes
#include "cmcAttributedObject.h"	// Document is a AttributedObject
#include "cmcCollection.h"		// Documents must be in Collections
#include "cmcAnnotation.h"		// Documents have Annotations
#include "cmcAnnotationSet.h"		// Document has a AnnotationSet
#include "cmcByteSequence.h"		// Document has a ByteSequence
#include "cmcSet.h"			// Documents use Sets as input parms
#include "cmcDocMgrObject.h"		// Has a base class of this

// Document is an Attributed Object containing data (text or otherwise)
#ifndef __GNUG__
class Document : public AttributedObject, public DocumentManagerObject
#else
class Document : public AttributedObject
#endif

{
  private:
	Collection &Parent;		// Parent Collection of Document
	char *Id;			// Document's Internal ID
	char *ExternalId;		// Document's External ID
	ByteSequence *pRawData;		// Text of the Document
	AnnotationSet Annotations;	// Document's Annotations
	char *OldExternalId;		// External Id before any change
	int Changed;			// flag to indicate if Document is
					// changed

	void Cleanup(void);		// clean out allocated memory

  public:
	// TIPSTER functions
	Document(Collection &NewParent, const char *NewExternalId, 
		const ByteSequence *pNewRawData, AnnotationSet &NewAnnotations, 
		Set<Attribute> &NewAttributes);
					// Constructor
	Document(const char *SgmlText, Collection &NewParent, 
		 const char *NewExternalId);
					// Constructor
	~Document(void);		// Destructor
	void Annotate(const char *AnnotatorName);
					// Annotates the Document
	char *WriteSGML(AnnotationSet &NewAnnotations, 
		Set<char*> &AnnotationPrecedence) const;
					// Converts Annotation to SGML text
	Collection &GetParent(void) const;
					// Returns the Parent component
	virtual Document *CopyBare(Collection &NewParent);
					// Copy document RawData and ExternalId
	virtual Document *CopyDocument(Collection &NewParent);
					// Copy all elements of the Document
	const char *GetId(void) const;	// Returns the (internal) ID
	const char *GetExternalId(void) const;
					// Returns the ExternalId component
	void SetExternalId(const char* NewId);
					// Sets a new ExternalID
	const ByteSequence *GetRawData(void) const; 
					// Returns the RawData component
	AnnotationSet &GetAnnotations(void);
					// Returns the Annotations component
	const AnnotationSet &GetAnnotations(void) const;
					// Returns the Annotations component
	const char *AddAnnotation(Annotation &NewAnnotation);
					// Adds Annotation to Annotations
	void RemoveAnnotation(const char *Id);
					// Removes the named Annotation
	Annotation &GetAnnotation(const char* Id) const;
					// Returns the named Annotation
	AnnotationSet *SelectAnnotations(const char *Type, 
		Set<Attribute> &Constraints) const;
					// Returns AnnotationSet containing
					// only the selected annotations
	void DeleteAnnotations(const char *Type, Set<Attribute> &Constraints);
					// Deletes Annotations matching
					// the given criteria
	AnnotationSet *AnnotationsAt(int Position) const;
					// Returns Annotations at a given 
					// position
	AnnotationSet *NextAnnotations(int Position) const;
					// Returns first set of Annotations
					// after Position

	// TIPSTER additions
	static const char *ClassLabel;	// The name of this class
	
	Document(Collection &NewParent, istream &);
					// Constructor from buffer
	Document(const Document &Base);	// copy constructor
	void SetId(const char *NewId);	// Set the (internal) ID
	const char *GetOldExternalId(void) const;
					// Returns the OldExternalId component
	void ClearOldExternalId(void);	// Sets OldExternalId to NULL
	void Sync(void);		// Syncs in-memory version of 
					// document with vesion in Collection
	void WriteToStream(ostream&) const;
					// write text version to stream
	Document *Copy(void) const;	// copy this Document
	virtual Document &CastToDocument(void);
					// downcast function
	virtual const Document &CastToDocument(void) const;
					// downcast function
	virtual const char *GetClass(void) const;
					// Get the class of this
};

#endif
