//
// Module Name:		cmcDocumentReference.h
//
// CSCI/CSC/CSU:	CMC/DocumentReference
//
// Author:		Ken Kolda
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	.h file for DocumentReference.  A DocumentReference is a
//	reference to a Document.
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           12/15/95    kolda    Initial version
//

#ifndef _cmcDocumentReference_h
#define _cmcDocumentReference_h

#include <iostream.h>			// to allow I/O of this

#include "cmcObjectReference.h"		// base class of thsi
#include "cmcAttributeValueType.h"	// type code for this
#include "cmcDocument.h"		// in a constructor
#include "cmcDocMgrObject.h"		// Has a base class of this

// Provides an Attribute that is a reference to a CMC Document
#ifndef __GNUG__
class DocumentReference : public ObjectReference, public DocumentManagerObject
#else
class DocumentReference : public ObjectReference
#endif

{
  private:
	char *CollectionName;		// The Collection containing the doc
	char *DocumentId;		// ID of the Document

	virtual void Write(ostream &Output) const;
					// write to output
	void Cleanup(void);		// cleanup allocate memory

  public:
	// TIPSTER functions
	DocumentReference(Document &ReferencedDocument);
					// Constructor
	DocumentReference(istream &Input);
					// construct from input
	const char *GetCollectionName(void) const;
					// Returns CollectionName component
	const char *GetDocumentId(void) const;
					// Returns the DocumentId component

	// TIPSTER RFC functions
	DocumentReference(const char *NewCollectionName, 
			  const char *NewDocumentId);
					// construct from data

	// TIPSTER additions
	static const char *ClassLabel;	// The name of this class

	DocumentReference(void);	// empty constructor
	DocumentReference(const DocumentReference &Base);
					// copy constructor
	~DocumentReference(void);	// Destructor
	AttributeValueType TypeOf(void) const;
					// Returns "DocumentReference"
	virtual ObjectReference *Copy(void) const;
 					// produce a copy of this
	virtual int operator==(const ObjectReference&) const;               
				       // test equality 
	DocumentReference &operator=(const DocumentReference &BaseDocument);
					// assignment operator
	virtual DocumentReference &CastToDocumentReference(void);
					// downcast function
	virtual const DocumentReference &CastToDocumentReference(void) const;
					// downcast function
	virtual const char *GetClass(void) const;
					// Get the class of this
};

#endif
