//
// Module Name:		cmcError.h
//
// CSCI/CSC/CSU:	CMC/Error
//
// Author:		Joe Dzikiewicz
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	.h containing the various types of errors that CMC can generate.
//	Each of these is a class that can be raised as an exception.
//	They are all put into the LogiconErrors class to preserve the
//	system namespace.
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           12/27/95    jd_2     Initial version
//

#ifndef _cmcError_h
#define _cmcError_h

class LogiconErrors
{
    public:

	class TipsterError
	{
	    private:
		char *Location;				// location tag

	    public:
		TipsterError(const char *NewLocation);	// constructor
		virtual ~TipsterError(void);		// destructor
		const char *GetLocation(void) const;	// get Location name
		virtual const char *GetLabel(void) const = 0;	
							// get error name
	};

	class MemoryAllocation : public TipsterError
	{
	    private:
		static const char *Label;		// label string for this

	    public:
		MemoryAllocation(const char *NewLocation);
							// constructor
		MemoryAllocation(const MemoryAllocation&);
							// copy constructor
		virtual const char *GetLabel(void) const;
							// get error name
	};

	class OutOfBounds : public TipsterError
	{
	    private:
		static const char *Label;		// label string for this

	    public:
		OutOfBounds(const char *NewLocation); 	// constructor
		OutOfBounds(const OutOfBounds &);	// copy constructor
		virtual const char *GetLabel(void) const;
							// get error name
	};

	class NotFound : public TipsterError
	{
	    private:
		static const char *Label;		// label string for this

	    public:
		NotFound(const char *NewLocation);	// constructor
		NotFound(const NotFound&);		// copy constructor
		virtual const char *GetLabel(void) const;
							// get error name
	};

	class AlreadyPresent : public TipsterError
	{
	    private:
		static const char *Label;		// label string for this

	    public:
		AlreadyPresent(const char *NewLocation);// constructor
		AlreadyPresent(const AlreadyPresent&);	// copy constructor
		virtual const char *GetLabel(void) const;
							// get error name
	};

	class InvalidObject : public TipsterError
	{
	    private:
		static const char *Label;		// label string for this

	    public:
		InvalidObject(const char *NewLocation); // constructor
		InvalidObject(const InvalidObject&);	// copy constructor
		virtual const char *GetLabel(void) const;
							// get error name
	};
	
	class InvalidType : public TipsterError
	{
	    private:
		static const char *Label;		// label string for this

	    public:
		InvalidType(const char *NewLocation); 	// constructor
		InvalidType(const InvalidType&);	// copy constructor
		virtual const char *GetLabel(void) const;
							// get error name
	};

	class Format : public TipsterError
	{
	    private:
		static const char *Label;		// label string for this

	    public:
		Format(const char *NewLocation);	// constructor
		Format(const Format &);			// copy constructor
		virtual const char *GetLabel(void) const;
							// get error name
	};

	class Open : public TipsterError
	{
	    private:
		static const char *Label;		// label string for this

	    public:
		Open(const char *NewLocation);	 	// constructor
		Open(const Open&);			// copy constructor
		virtual const char *GetLabel(void) const;
							// get error name
	};

	class Seek : public TipsterError
	{
	    private:
		static const char *Label;		// label string for this

	    public:
		Seek(const char *NewLocation);	 	// constructor
		Seek(const Seek&);			// copy constructor
		virtual const char *GetLabel(void) const;
							// get error name
	};

	class Read : public TipsterError
	{
	    private:
		static const char *Label;		// label string for this

	    public:
		Read(const char *NewLocation);	 	// constructor
		Read(const Read&);			// copy constructor
		virtual const char *GetLabel(void) const;
							// get error name
	};

	class Write : public TipsterError
	{
	    private:
		static const char *Label;		// label string for this

	    public:
		Write(const char *NewLocation); 	// constructor
		Write(const Write&);			// copy constructor
		virtual const char *GetLabel(void) const;
	};

	class Delete : public TipsterError
	{
	    private:
		static const char *Label;		// label string for this

	    public:
		Delete(const char *NewLocation); 	// constructor
		Delete(const Delete&);			// copy constructor
		virtual const char *GetLabel(void) const;
	};

	class Lock : public TipsterError
	{
	    private:
		static const char *Label;		// label string for this

	    public:
		Lock(const char *NewLocation);	 	// constructor
		Lock(const Lock&);			// copy constructor
		virtual const char *GetLabel(void) const;
							// get error name
	};

	class Parameter : public TipsterError
	{
	    private:
		static const char *Label;		// label string for this

	    public:
		Parameter(const char *NewLocation); 	// constructor
		Parameter(const Parameter&);		// copy constructor
		virtual const char *GetLabel(void) const;
							// get error name
	};
};



#endif
