//
// Module Name:		cmcIndexEntry.cc
//
// CSCI/CSC/CSU:	CMC/IndexEntry
//
// Author:		Joe Dzikiewicz
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//			RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	Code for IndexEntry.  An IndexEntry is a piece of data stored in
//	an IndexBlock as part of an Index.  For more details on how this
//	fits into an Index, see the Implementation Notes comment in
//	cmcIndex.cc.
//
// Function List:
//	IndexEntry::IndexEntry() - There are 2 constructors herein
//	IndexEntry::~IndexEntry() - Destructor
//	IndexEntry::GetId() - Get the ID of this
//	IndexEntry::SetId() - Set the ID of this
//	IndexEntry::GetLocation() - Get the Location of this
//	IndexEntry::SetLocation() - Set the Location of this
//	IndexEntry::Sync() - Synchronize this to file
//	IndexEntry::CastToInnerIndexEntry() - Downcast function
//	IndexEntry::CastToLeafIndexEntry() - Downcast function
//
// Other Modules Called:
//	Error - for exception classes
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           1/2/96      jd_2     Initial version
//


#include <iostream.h>			// for I/O
#include <string.h>			// for string functions

#include "cmcIndexEntry.h"		// for declaration of this
#include "cmcError.h"			// for exception classes

//
// Function Name:	IndexEntry::IndexEntry()
//
// CSCI/CSC/CSU:	CMC/IndexEntry
//
// Description:		Constructor.
//
// Parameters:		NewId - ID to store in the Entry
//			NewLocation - Location to store in the Entry
//
// Return Value:	None
//
IndexEntry::IndexEntry(const char *NewId, const Location &NewLocation) : 
		DataLocation(NewLocation)
{
    // put in the ID
    SetId(NewId);
}




//
// Function Name:	IndexEntry::IndexEntry()
//
// CSCI/CSC/CSU:	CMC/IndexEntry
//
// Description:		Constructor.
//
// Parameters:		None
//
// Return Value:	None
//
IndexEntry::IndexEntry() : DataLocation(Location(0,0))
{
    strcpy(Id, "");
}



//
// Function Name:	IndexEntry::~IndexEntry()
//
// CSCI/CSC/CSU:	CMC/IndexEntry
//
// Description:		Destructor.
//
// Parameters:		None
//
// Return Value:	None
//
IndexEntry::~IndexEntry()
{
}



//
// Function Name:	IndexEntry::GetId()
//
// CSCI/CSC/CSU:	CMC/IndexEntry
//
// Description:		Get the ID associated with this entry.
//
// Parameters:		None
//	
// Return Value:	The Id component.
//
const char *IndexEntry::GetId() const
{
    return Id;
}



//
// Function Name:	IndexEntry::SetId()
//
// CSCI/CSC/CSU:	CMC/IndexEntry
//
// Description:		Set the Id component of this
//
// Parameters:		NewId - New value of the Id component
//
// Return Value:	None
//
void IndexEntry::SetId(const char *NewId)
{
    // copy in new ID
    strncpy(Id, NewId, DocumentIdLength);
    Id[DocumentIdLength] = '\0';
}




//
// Function Name:	IndexEntry::GetLocation()
//
// CSCI/CSC/CSU:	CMC/IndexEntry
//
// Description:		Get the Location associated with this entry.
//
// Parameters:		None
//	
// Return Value:	The Location component.
//
const Location &IndexEntry::GetLocation() const
{
    return DataLocation;
}



//
// Function Name:	IndexEntry::SetLocation()
//
// CSCI/CSC/CSU:	CMC/IndexEntry
//
// Description:		Set the Location component of this
//
// Parameters:		NewLocation - New value of the Location component
//
// Return Value:	None
//
void IndexEntry::SetLocation(const Location &NewLocation)
{
    DataLocation.SetVolume(NewLocation.GetVolume());
    DataLocation.SetOffset(NewLocation.GetOffset());
}



//
// Function Name:	IndexEntry::Sync()
//
// CSCI/CSC/CSU:	CMC/IndexEntry
//
// Description:		Default for a virtual function: this does nothing.
//
// Parameters:		None
//
// Return Value:	None
//
void IndexEntry::Sync()
{
}



//
// Function Name:	IndexEntry::CastToInnerIndexEntry()
//
// CSCI/CSC/CSU:	CMC/IndexEntry
//
// Description:		Default downcast function that throws an exception.
//
// Parameters:		None
//
// Return Value:	NULL to satisy calling format.
//
InnerIndexEntry &IndexEntry::CastToInnerIndexEntry()
{
    throw LogiconErrors::InvalidType("IndexEntry::CastToInnerIndexEntry()");

    return *(InnerIndexEntry*)NULL;
}



//
// Function Name:	IndexEntry::CastToInnerIndexEntry()
//
// CSCI/CSC/CSU:	CMC/IndexEntry
//
// Description:		Default downcast function that throws an exception.
//
// Parameters:		None
//
// Return Value:	NULL to satisy calling format.
//
const InnerIndexEntry &IndexEntry::CastToInnerIndexEntry() const
{
    throw LogiconErrors::InvalidType("IndexEntry::CastToInnerIndexEntry()");

    return *(InnerIndexEntry*)NULL;
}


//
// Function Name:	IndexEntry::CastToLeafIndexEntry()
//
// CSCI/CSC/CSU:	CMC/IndexEntry
//
// Description:		Default downcast function that throws an exception.
//
// Parameters:		None
//
// Return Value:	NULL to satisy calling format
//
LeafIndexEntry &IndexEntry::CastToLeafIndexEntry()
{
    throw LogiconErrors::InvalidType("IndexEntry::CastToLeafIndexEntry()");

    return *(LeafIndexEntry*)NULL;
}



//
// Function Name:	IndexEntry::CastToLeafIndexEntry()
//
// CSCI/CSC/CSU:	CMC/IndexEntry
//
// Description:		Default downcast function that throws an exception.
//
// Parameters:		None
//
// Return Value:	NULL to satisy calling format
//
const LeafIndexEntry &IndexEntry::CastToLeafIndexEntry() const
{
    throw LogiconErrors::InvalidType("IndexEntry::CastToLeafIndexEntry()");

    return *(LeafIndexEntry*)NULL;
}




