//
// Module Name:		cmcIndexEntry.h
//
// CSCI/CSC/CSU:	CMC/IndexEntry
//
// Author:		Joe Dzikiewicz
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	.h for IndexEntry.  IndexEntry is an abstract class that is an
//	entry in an IndexBlock, mapping one ID to one item.
//
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           12/15/95    jd_2     Initial version
//

#ifndef _cmcIndexEntry_h
#define _cmcIndexEntry_h

#include <iostream.h>			// to allow I/O of this

#include "cmcLocation.h"		// Location of this
#include "cmcMisc.h"			// miscellaneous defines for this

class InnerIndexEntry;			// to return values
class LeafIndexEntry;			// to return values

// An IndexEntry is an item in a B-Tree index block.
class IndexEntry
{
    private:
	char Id[DOCUMENT_ID_LENGTH + 1];// Id associated with this entry
	Location DataLocation;		// Location associated with this entry

    public:
	IndexEntry(const char *NewId, const Location &NewLocation);
					// construct with Id and Location
	IndexEntry(void);		// construct with nothing
	virtual ~IndexEntry();		// destructor
	const char *GetId(void) const;	// get the Id component
	void SetId(const char *NewId);	// set the Id component
	const Location &GetLocation(void) const;
					// get the Location component
	void SetLocation(const Location &NewLocation);
					// set the Location component
	virtual void Sync(void);	// synchronize output to file
	virtual void Write(ostream &Output) const = 0;
					// write out a copy of this to stream
	virtual InnerIndexEntry &CastToInnerIndexEntry(void);
					// downcast to an InnerIndexEntry
	virtual const InnerIndexEntry &CastToInnerIndexEntry(void) const;
					// downcast to an InnerIndexEntry
	virtual LeafIndexEntry &CastToLeafIndexEntry(void);
					// downcast to a LeafIndexEntry
	virtual const LeafIndexEntry &CastToLeafIndexEntry(void) const;
					// downcast to a LeafIndexEntry
};

#endif
