//
// Module Name:		cmcInnerIndexEntry.h
//
// CSCI/CSC/CSU:	CMC/InnerIndexEntry
//
// Author:		Joe Dzikiewicz
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	.h for InnerIndexEntry.  An InnerIndexEntry is a single entry for
//	an InnerIndexBlock.  As such, it maps a single ID to another
//	IndexBlock.
//
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           12/15/95    jd_2     Initial version
//

#ifndef _cmcInnerIndexEntry_h
#define _cmcInnerIndexEntry_h

class InnerIndexEntry;                  // Incomplete Declaration

#include <iostream.h>			// to allow I/O

#include "cmcInnerIndexBlock.h"		// parent type of this
#include "cmcIndexBlock.h"		// item in this entry
#include "cmcIndex.h"			// index in which this is
#include "cmcIndexEntry.h"		// parent class of this

// InnerIndexEntry is a single entry in an InnerIndexBlock
class InnerIndexEntry : public IndexEntry
{
    private:
	IndexBlock *pBlock;			// the data block
	int Offset;				// offset to the data block

    public:
	InnerIndexEntry(istream &Input);	// construct by reading it in
	InnerIndexEntry(IndexBlock *pNewBlock);	// construct with a block
	~InnerIndexEntry(void);			// destructor
	void Sync(void);			// synchronize output to file
	virtual void Write(ostream &Output) const;
						// write a stream version of it
	int GetOffset(void) const;		// return the Offset component
	void ClearBlock(void);			// clear out the block from this
	int IsBlockLoaded(void) const;		// is the block loaded?
	IndexBlock &GetBlock(InnerIndexBlock &Parent);
						// get the block from this
	IndexBlock *ExtractBlock(InnerIndexBlock &Parent);
						// get the block and remove from
						//     here
	virtual InnerIndexEntry &CastToInnerIndexEntry(void);
						// downcast to this
	virtual const InnerIndexEntry &CastToInnerIndexEntry(void) const;
						// downcast to this
};

#endif

