//
// Module Name:		cmcLeafIndexBlock.h
//
// CSCI/CSC/CSU:	CMC/LeafIndexBlock
//
// Author:		Joe Dzikiewicz
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	.h for LeafIndexBlock.  A LeafIndexBlock is a type of IndexBlock
//	that is a leaf of the Index tree.  As such, it maps a set of 
//	ID's to their volume and offset numbers.
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           12/15/95    jd_2     Initial version
//

#ifndef _cmcLeafIndexBlock_h
#define _cmcLeafIndexBlock_h

#include <iostream.h>			// to allow I/O 

#ifdef __GNUG__
class IndexBlock;
#endif
class LeafIndexBlock;                   // Incomplete Declaration

#ifdef __GNUG__
#include "cmcIndex.h"		// this tracks its block
#endif
#include "cmcIndexBlock.h"		// this tracks its block
#include "cmcLocation.h"		// data within this
#include "cmcLeafIndexEntry.h"		// data within this

// LeafIndexBlock is a B-Tree block used in the Index file.
// This is a block that is a leaf.
class LeafIndexBlock : public IndexBlock
{
  private:
	static const int LowBlockThreshold;
					// low number of entries in a block
	static const int HighBlockThreshold;
					// high number of entries in a block

	void ReadBlock(istream &Input); // read input from stream

  public:
      	LeafIndexBlock(Index &NewIndex); // construct empty new block
	LeafIndexBlock(Index &NewIndex, InnerIndexBlock *pNewParent, 
			int Offset, istream &Input);
					// read data from input
					// do NOT take ownership of pNewParent
	LeafIndexBlock(Index &NewIndex, InnerIndexBlock *pNewParent, 
			int NewOffset);
					// construct block by reading it in
					// do NOT take ownership of pNewParent
	virtual ~LeafIndexBlock(void);	// destructor
	
	virtual const Location &FindId(const char *Id) const;
					// locate block for an Id
	virtual void Remove(const char *Id, const Location &Place);
					// remove an Id
	virtual void AddId(const char *Id, const Location &Place);
					// add an Id to the block
	virtual IndexBlock &FindIndexBlock(const char *Id);
					// find the base block for the Id
	virtual IndexBlock &FindIndexBlock(const char *Id, 
					   const Location &Place);
					// find the base block for the Item
	
	virtual void Sync(void);	// synchronize this to file
	virtual int MaxLength(void) const;
					// get the max number of entries herein
	virtual IndexBlockType GetType(void) const;
					// get the type of this
	virtual IndexBlock *CreateNewBlock(void) const;
					// construct a block in this's image
	virtual void Display(ostream &Output, int Indent);
					// display this to Output
};

#endif
