//
// Module Name:		cmcLeafIndexEntry.cc
//
// CSCI/CSC/CSU:	CMC/LeafIndexEntry
//
// Author:		Joe Dzikiewicz
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//			RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	Code for LeafIndexEntry.  A LeafIndexEntry is an IndexEntry kept in
//	a LeafIndexBlock.  It is part of the Index family of classes.  For
//	more details, see the Implementation Notes comment in cmcIndex.cc.
//
// Function List:
//	LeafIndexEntry::LeafIndexEntry() - There are two constructors here
//	LeafIndexEntry::Write() - Write to an output stream
//	LeafIndexEntry::CastToLeafIndexEntry() - Downcast function
//
// Other Modules Called:
//	Misc - for string I/O
//	Error - Used for exceptions
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           1/2/96      jd_2     Initial version
//


#include <iostream.h>			// for I/O
#include <stddef.h>			// for NULL

#include "cmcLeafIndexEntry.h"		// for declarations of this
#include "cmcMisc.h"			// for string I/O
#include "cmcError.h"			// for exception classes


//
// Function Name:	LeafIndexEntry::LeafIndexEntry()
//
// CSCI/CSC/CSU:	CMC/LeafIndexEntry
//
// Description:		Construct a LeafIndexEntry by reading it from an
//			input stream.
//
// Parameters:		Input - the input stream
//
// Return Value:	None
//
LeafIndexEntry::LeafIndexEntry(istream &Input) : IndexEntry()
{
    char *NewId = NULL;				// to hold the ID
   
    try
    {
        if((NewId = new char[DocumentIdLength + 1]) == NULL)
	    throw LogiconErrors::MemoryAllocation(
			"LeafIndexEntry::LeafIndexEntry(istream&)");

    	// get the Id
    	Input.read(NewId, DocumentIdLength);
    	NewId[DocumentIdLength] = '\0';
    	SetId(NewId);

    	// get the data
    	int Volume;			// to hold volume
    	int Offset;			// to hold offset

    	Input.read((char *)&Volume, sizeof(Volume));
    	Input.read((char *)&Offset, sizeof(Offset));

    	// test input
    	if(!Input)
	    throw LogiconErrors::Read(
			"LeafIndexEntry::LeafIndexEntry(istream&)");

	SetLocation(Location(Volume, Offset));

	delete[] NewId;
    }
    catch(...)
    {
	if(NewId != NULL)
	    delete[] NewId;
	throw;
    }
}



//
// Function Name:	LeafIndexEntry::LeafIndexEntry()
//
// CSCI/CSC/CSU:	CMC/LeafIndexEntry
//
// Description:		Constructor given the elements that go in this.
//
// Parameters:		NewId - The ID for this
//			NewLeafLocation - The location to store
//
// Return Value:	None
//
LeafIndexEntry::LeafIndexEntry(const char *NewId, 
			       const Location &NewLeafLocation) :
	IndexEntry(NewId, NewLeafLocation)
{
}




//
// Function Name:	LeafIndexEntry::Write()
//
// CSCI/CSC/CSU:	CMC/LeafIndexEntry
//
// Description:		Write this to an output stream.
//
// Parameters:		Output - The output stream.
//
// Return Value:	None
//
void LeafIndexEntry::Write(ostream &Output) const
{
    // write the Id
    Output.write(GetId(), DocumentIdLength);

    // write the data
    int i = GetLocation().GetVolume();
    Output.write((char *)&i, sizeof(i));
    i = GetLocation().GetOffset();
    Output.write((char *)&i, sizeof(i));

    // test output
    if(!Output)
	throw LogiconErrors::Write("LeafIndexEntry::Write(ostream&)");
}



//
// Function Name:	LeafIndexEntry::CastToLeafIndexEntry()
//
// CSCI/CSC/CSU:	CMC/LeafIndexEntry
//
// Description:		Downcast function.
//
// Parameters:		None
//
// Return Value:	This entry.
//
LeafIndexEntry &LeafIndexEntry::CastToLeafIndexEntry()
{
    return *this;
}


//
// Function Name:	LeafIndexEntry::CastToLeafIndexEntry()
//
// CSCI/CSC/CSU:	CMC/LeafIndexEntry
//
// Description:		Downcast function.
//
// Parameters:		None
//
// Return Value:	This entry.
//
const LeafIndexEntry &LeafIndexEntry::CastToLeafIndexEntry() const
{
    return *this;
}
