//
// Module Name:		cmcLocation.h
//
// CSCI/CSC/CSU:	CMC/Location
//
// Author:		Joe Dzikiewicz
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	.h for Location.  A Location contains a volume and offset number.
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           12/15/95    jd_2     Initial version
//

#ifndef _cmcLocation_h
#define _cmcLocation_h


// Location indicates a location in a file
class Location
{
    private:
	int Volume;			// the volume
	int Offset;			// the offset

    public:
	Location(int NewVolume = -1, int NewOffset = -1) : 
			Volume(NewVolume), Offset(NewOffset) {}
					// constructor
	Location(const Location &Model) : 
		Volume(Model.Volume), Offset(Model.Offset) {}
					// copy constructor
	int GetVolume(void) const { return Volume; }
					// get the Volume
	int GetOffset(void) const { return Offset; }
					// get the Offset
	void SetVolume(int NewVolume) { Volume = NewVolume; }
					// set the Volume
	void SetOffset(int NewOffset) { Offset = NewOffset; }
					// set the Offset
	int operator==(const Location &Tester) const
		{ return Volume == Tester.Volume && Offset == Tester.Offset; }
					// test equivalence
	int operator!=(const Location &Tester) { return !(*this == Tester); }
					// test non-equivalence
	int operator<(const Location &Tester) const
		{ return Volume < Tester.Volume ||
			(Volume == Tester.Volume && Offset < Tester.Offset); }
					// test < relation
	int operator<=(const Location &Tester) const
		{ return Volume < Tester.Volume ||
			(Volume == Tester.Volume && Offset <= Tester.Offset); }
					// test <= relation
	int operator>(const Location &Tester) const
		{ return Tester < *this; }
					// test > relation
	int operator>=(const Location &Tester) const
		{ return Tester <= *this; }
					// test >= relation
};

#endif
