//
// Module Name:		cmcMisc.cc
//
// CSCI/CSC/CSU:	CMC/Misc
//
// Author:		Joe Dzikiewicz
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//			RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	This contains miscellaneous functions used in the implementation of
//	other CMC modules.
//
// Function List:
//	WriteString() - write out a string and its length to a stream
//	ReadString() - read in a stream using the WriteString() format
//	Indent() - Write an indentation to an output stream
//
// Other Modules Called:
//	Error - Used for exceptions
//
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//
//

#include <iostream.h>		// for I/O
#include <stddef.h>		// for NULL
#include <string.h>		// for string functions

#include "cmcMisc.h"		// for string I/O
#include "cmcError.h"		// for exception classes



const int DocumentIdLength = DOCUMENT_ID_LENGTH;// max length of a Doc Id
static const int MaxStringLength = 1000000;	// max length of a string

//
// Function Name:	WriteString()
//
// CSCI/CSC/CSU:	CMC/Misc
//
// Description:		Write a string to a stream in the following format:
//
//				<length> space <string>
//
// Parameters:		String - the string to write
//			Output - the stream to write to
//
// Return Value:	None
//
void WriteString(const char *String, ostream &Output)
{
    if(String == NULL)
	Output << "0 ";
    else
	Output << strlen(String) << ' ' << String;

    // test output
    if(!Output)
	throw LogiconErrors::Write("WriteString(char*, ostream&)");
}


//
// Function Name:	ReadString()
//
// CSCI/CSC/CSU:	CMC/Misc
//
// Description:		Read a string from a stream in the WriteString
//			format.  Allocate space for that string and return
//			it.
//
// Parameters:		Input - stream to read from
//
// Return Value:	The string read in.  This will need to be deleted by
//			the caller.
//
char *ReadString(istream &Input)
{
    int Length;		// length of string
    char *String;	// the string
    char ch;		// a temp character

    Input >> Length;	
    if(Length == 0)
	String = NULL;
    else if(Length < 0 || Length > MaxStringLength)
	throw LogiconErrors::InvalidObject("ReadString(istream)");
    else
    {
	// skip blank
	Input.get(ch);

	if((String = new char[Length + 1]) == NULL)
	    throw LogiconErrors::MemoryAllocation("ReadString(istream&)");

	if(!Input.get(String, Length + 1, '\0'))
	{
	    delete[] String;
	    throw LogiconErrors::Read("ReadString(istream&)");
	}
    }

    return String;
}



//
// Function Name:	Indent()
//
// CSCI/CSC/CSU:	CMC/Misc
//
// Description:		Indent data on an Output stream Level levels
//
// Parameters:		Output - Stream to output to
//			Level - number of levels to indent
//
// Return Value:	None
//
void Indent(ostream &Output, int Level)
{
    // do for all indent levels
    for(int i = 0; i < Level; ++i)
	Output << "   ";

    if(!Output)
	throw LogiconErrors::Write("Indent(ostream&, int)");
}
