//
// Module Name:		cmcObjectReference.h
//
// CSCI/CSC/CSU:	CMC/ObjectReference
//
// Author:		Ken Kolda
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	.h for ObjectReference.  ObjectReference is an abstract class
//	that represents a reference to some specific object.
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           12/15/95    kolda    Initial version
//

#ifndef _cmcObjectReference_h
#define _cmcObjectReference_h

#include <iostream.h>				// to allow I/O

#include "cmcAttributeValueType.h"		// type of AttributeValue
#include "cmcDocMgrObject.h"			// Has a base class of this

// ObjectReference allows other CMC objects to be Attributes
class ObjectReference : public DocumentManagerObject
{
  private:
	virtual void Write(ostream &Output) const = 0;
						// write to output
	friend ostream &operator<<(ostream&, ObjectReference&);
						// writes this out

  public:
	// TIPSTER functions
	virtual ~ObjectReference(void) {}	// Virtual Destructor

	// TIPSTER additions
	virtual AttributeValueType TypeOf(void) const = 0;
						// All derived classes must 
						// provide function to return 
						// type of reference
	virtual ObjectReference *Copy(void) const = 0;
						// produce a copy of this
	virtual int operator==(const ObjectReference&) const = 0;
					       // test equality 
	virtual ObjectReference &CastToObjectReference(void) { return *this; }
						// downcast for this
	virtual const ObjectReference &CastToObjectReference(void) const
				{ return *this; }
						// constant downcast for this
};



inline ostream &operator<<(ostream &Output, ObjectReference &Ref)
{
    Ref.Write(Output);
    return Output;
}

#endif
