//
// Module Name:		cmcObjectReferenceVal.h
//
// CSCI/CSC/CSU:	CMC/ObjectReferenceValue
//
// Author:		Ken Kolda
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	.h for ObjectReferenceValue.  An ObjectReferenceValue is an
//	AttributeValue that contains a reference to some object.
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           12/15/95    kolda    Initial version
//

#ifndef _cmcObjectReferenceVal_h
#define _cmcObjectReferenceVal_h

#include <iostream.h>			// to allow I/O

class ObjectReferenceValue;

#include "cmcAttributeValueType.h"	// to allow return of this type
#include "cmcAttributeValue.h"		// base class for this
#include "cmcObjectReference.h"		// data within this
#include "cmcDocMgrObject.h"		// Has a base class of this

// ObjectReferenceValue permits attributes to reference other CMC objects
#ifndef __GNUG__
class ObjectReferenceValue : public AttributeValue, public DocumentManagerObject
#else
class ObjectReferenceValue : public AttributeValue
#endif

{
  private:
	ObjectReference *pValue;	// The Value of this Attribute

  public:
	// TIPSTER functions
	ObjectReferenceValue(ObjectReference &NewValue);
					// Constructor
	~ObjectReferenceValue(void);	// Destructor
	AttributeValueType TypeOf(void) const;
					// Returns the type of reference
	ObjectReference &GetValue(void) const;
					// Returns the Value component

	// TIPSTER additions
	static const char *ClassLabel;	// The name of this class
	
	ObjectReferenceValue(AttributeValueType, istream &);
					// construct from input
	AttributeValue *Copy(void) const;
					// Return copy of this
	virtual void WriteToStream(ostream &) const;
					// write this to a stream
	virtual int operator==(const AttributeValue&) const;
					// test equality
	virtual const char *GetClass(void) const;
					// Get the class of this
	virtual ObjectReferenceValue &CastToObjectReferenceValue(void);
					// downcast function
	virtual const ObjectReferenceValue &CastToObjectReferenceValue(void) 
				const;
					// downcast function
};

#endif
