//
// Module Name:		cmcPersistentCollection.h
//
// CSCI/CSC/CSU:	CMC/PersistentCollection
//
// Author:		Joe Dzikiewicz
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	.h for PersistentCollection.  A PersistentCollection is a Collection
//	maintained in persistent storage.  This is actually a surrogate for
//	the real PersistentCollection, which is kept as a multi-referenced
//	reference in a reference cache.
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           12/15/95    jd_2     Initial version
//

#ifndef _cmcPersistentCollection_h
#define _cmcPersistentCollection_h

#include "cmcSet.h"			// to hold set of Volumes
#include "cmcVolume.h"			// to store Documents
#include "cmcIndex.h"			// to index Documents
#include "cmcAttributeValue.h"		// to override AttributedObject methods
#include "cmcAttribute.h"		// to override AttributedObject methods
#include "cmcDocument.h"		// items kept in this
#include "cmcPersistentCollectionStub.h"// base class for this
#include "cmcRealPersistentCollection.h"// does the work for this

// PersistentCollection is a Collection with Permanent Storage
class PersistentCollection : public PersistentCollectionStub
{
  private:
	RealPersistentCollection *pCollection;
					// the actual collection
	RealPersistentCollection::Iterator *pIterator;
					// the walkthrough iterator

  public:
	// TIPSTER functions
	PersistentCollection(const char *Name, 
			     const Set<Attribute> &Attributes);
					// Constructor
	PersistentCollection(const char *Name, const Set<Attribute> &Attributes,
		int NewVolumeCount, int BlockSize); 
					// Constructor
	PersistentCollection(const char *Name);
					// Constructor from persistent copy
	~PersistentCollection(void);	// Destructor

	virtual int Length(void) const;	// Returns number of Documents
					//  in Collection
	virtual void RemoveDocument(const char *Id);	
					// Removes the Document with the
					// given internal ID from Collection
	virtual Document *GetDocument(const char *Id);
					// Returns Document with given ID
	virtual Document *FirstDocument(void);	
					// Returns first Document in Collection
	virtual Document *NextDocument(void);	
					// Returns next Document in Collection
	virtual Document *GetByExternalId(const char *ExternalId);
					// Returns Document with given
					// External ID
	virtual void AnnotateCollection(Collection&, const char *);
					// annotates documents in Collection
	virtual void Sync(void);	// Flushes changes to Collection
	static void Destroy(const char *Name);
					// Deletes the named Collection

	// replacements for AttributedObject functions
	virtual void PutAttribute(const char *Name, 
				  const AttributeValue &Value);
					// Adds an Attribute to the Collection
	virtual const AttributeValue *GetAttribute(const char *Name) const;
					// Returns the value of the attribute
					// with the given name
	virtual Set<Attribute> &GetAttributes(void);
					// Returns the entire set of attributes
	virtual const Set<Attribute> &GetAttributes(void) const;
					// Returns the entire set of attributes
	virtual int HasAttributes(Set<Attribute> &) const;
					// test if the object has the given
					// attributes
	virtual int IsAttributesChanged(void) const;
					// test if Attributes have changed
	virtual void ClearAttributesChanged(void);
					// clear changed Attributes flag

	// TIPSTER additions
	virtual void Store(Document &Document);	
					// Add the Document to the Collection
	virtual void Update(Document &Document);	
					// Update the Document in the Collection
};

#endif
