//
// Module Name:		cmcPersistentCollectionStub.h
//
// CSCI/CSC/CSU:	CMC/PersistentCollection
//
// Author:		Joe Dzikiewicz
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	.h for PersistentCollectionStub.  A PersistentCollectionStub 
//	defines the interface for a Collection maintained in persistent storage.
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           12/15/95    jd_2     Initial version
//

#ifndef _cmcPersistentCollectionStub_h
#define _cmcPersistentCollectionStub_h

#include "cmcSet.h"			// to hold set of Volumes
#include "cmcAttribute.h"		// to override AttributedObject methods
#include "cmcDocument.h"		// items kept in this
#include "cmcCollection.h"		// base class for this

// PersistentCollectionStub is a Collection with Permanent Storage
class PersistentCollectionStub : public Collection
{
    public:
	// TIPSTER functions
	PersistentCollectionStub(const char *NewName, 
			     const Set<Attribute> &NewAttributes) :
			Collection(NewName, NewAttributes) {}
					// Constructor
	PersistentCollectionStub(const char *NewName) : Collection(NewName) {}
					// Constructor
	virtual ~PersistentCollectionStub(void) {}
					// Destructor

	virtual int Length(void) const = 0;
					// Returns number of Documents
					//  in Collection
	virtual void RemoveDocument(const char *Id) = 0;	
					// Removes the Document with the
					// given internal ID from Collection
	virtual Document *GetDocument(const char *Id) = 0;
					// Returns Document with given ID
	virtual Document *FirstDocument(void) = 0;	
					// Returns first Document in Collection
	virtual Document *NextDocument(void) = 0;	
					// Returns next Document in Collection
	virtual Document *GetByExternalId(const char *ExternalId) = 0;
					// Returns Document with given
					// External ID
	virtual void AnnotateCollection(Collection&, const char *) = 0;
					// annotates documents in Collection
	virtual void Sync(void) = 0;	// Flushes changes to Collection

	// TIPSTER additions
	virtual void Store(Document &Document) = 0;	
					// Add the Document to the Collection
};

#endif
