//
// Module Name:		cmcPersistentObject.cc
//
// CSCI/CSC/CSU:	CMC/PersistentObject
//
// Author:		Joe Dzikiewicz
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//			RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	This contains the functions for the PersistentObject class.  A
//	PersistentObject is a virtual class that represents objects
//	that are kept in persistent storage.
//
//	This class does not actually provide any persistent storage.  It
//	is expected that the actual persistent storage of a class, and the
//	functions related to it, will be provided by each subclass of this.
//
// Function List:
//	PersistentObject::PersistentObject() - Constructor
//	PersistentObject::~PersistentObject() - Destructor
//	PersistentObject::GetName() - Get the name of the object
//	PersistentObject::CastToPersistentObject() - Downcast function
//
// Other Modules Called:
//	Error - Used for exceptions
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           11/17/95    jd_2     Initial version
//

#include <string.h>			// for standard string functions
#include <stddef.h>			// for NULL

#include "cmcPersistentObject.h"	// for declaration of this
#include "cmcError.h"			// for exception classes

//
// Function Name:	PersistentObject::PersistentObject()
//
// CSCI/CSC/CSU:	CMC/PersistentObject
//
// Description:		Construct a PersistentObject given its name.
//
// Parameters:		NewName - name of the PersistentObject
//
// Return Value:	None
//
PersistentObject::PersistentObject(const char *NewName)
{
    if(NewName == NULL)
	Name = NULL;
    else
    {
    	if((Name = new char[strlen(NewName) + 1]) == NULL)
	    throw LogiconErrors::MemoryAllocation(
		"PersistentObject::PersistentObject(char *)");
    	strcpy(Name, NewName);
    }
}


//
// Function Name:	PersistentObject::~PersistentObject()
//
// CSCI/CSC/CSU:	CMC/PersistentObject
//
// Description:		Destruct a PersistentObject
//
// Parameters:		None
//
// Return Value:	None
//
PersistentObject::~PersistentObject()
{
    if(Name != NULL)
    	delete[] Name;
}



//
// Function Name:	PersistentObject::GetName()
//
// CSCI/CSC/CSU:	CMC/PersistentObject
//
// Description:		Return the Name component of the PersistentObject.
//
// Parameters:		None
//
// Return Value:	The Name component
//
const char *PersistentObject::GetName() const
{
    return Name;
}



//
// Function Name:	PersistentObject::CastToPersistentObject()
//
// CSCI/CSC/CSU:	CMC/PersistentObject
//
// Description:		Downcast this to the current type.
//
// Parameters:		None
//
// Return Value:	*this
//
PersistentObject &PersistentObject::CastToPersistentObject()
{
    return *this;
}




//
// Function Name:	PersistentObject::CastToPersistentObject()
//
// CSCI/CSC/CSU:	CMC/PersistentObject
//
// Description:		Downcast this to the current type.
//
// Parameters:		None
//
// Return Value:	*this
//
const PersistentObject &PersistentObject::CastToPersistentObject() const
{
    return *this;
}


