//
// Module Name:		cmcPersistentObject.h
//
// CSCI/CSC/CSU:	CMC/PersistentObject
//
// Author:		Ken Kolda
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	Provide the class definition for PersistentObject.  This is a
//	virtual class.  A PersistentObject is an object that has some
//	degree of persistence.
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           11/14/95    kolda   Initial version
//

#ifndef _cmcPersistentObject_h
#define _cmcPersistentObject_h

#include <stddef.h>		// to get NULL

#include "cmcDocMgrObject.h"	// Has a base class of this

// Global Type Definitions
//typedef unsigned int Boolean;

// The PersistentObject class is an abstract class that provides for permanent
// storage for objects
class PersistentObject : public DocumentManagerObject
{
  private:
	char *Name;	    		// The name of the object

  public:
	// TIPSTER functions
	PersistentObject(const char *NewName = NULL);
					// Constructor 
	virtual ~PersistentObject(void);// Destructor
	virtual void Sync(void) = 0;	// Syncs in-memory copy with persistent
	 				// copy
	// virtual static void Destroy(const char* Name) = 0;
					// Destroys the PersistentObject with
					// the given name:
					// this is commented out because
					// all PersistentObject subclasses
					// must supply it
	const char *GetName(void) const;// Returns the Name component

	// TIPSTER additions
	virtual PersistentObject &CastToPersistentObject(void);
					// downcast function
	virtual const PersistentObject &CastToPersistentObject(void) const;
					// downcast function
};

#endif
