//
// Module Name:		cmcReference.h
//
// CSCI/CSC/CSU:	CMC/Reference
//
// Author:		Joe Dzikiewicz
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	Include file for a Reference.  A Reference is something kept in
//	a ReferenceCache.  It is a virtual base class for anything that
//	might be referenced.
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           2/22/96     jd_2     Initial version
//

#ifndef _cmcReference_h
#define _cmcReference_h

#include "cmcError.h"				// for exception classes

// the following are possible targets of downcasts
class RealPersistentCollection;

// a Reference is something that goes in a ReferenceCache
class Reference
{
    private:
	int ReferenceCount;			// count of references to this

    public:
	Reference(void) : ReferenceCount(0) {}	// constructor
	virtual ~Reference(void) {}		// destructor
	int GetReferenceCount(void) { return ReferenceCount; }
						// get ReferenceCount member
	void DecrementReferenceCount(void) { ReferenceCount--; }
						// decrement the ReferenceCount
	void IncrementReferenceCount(void) { ReferenceCount++; }
						// increment the ReferenceCount
	virtual const char *GetName(void) const = 0;
						// get the name of this

	// the following are downcast operators
	virtual RealPersistentCollection &CastToRealPersistentCollection(void)
		{ throw LogiconErrors::InvalidType(
				"Reference::CastToRealPersistentCollection()"); 
		  return *(RealPersistentCollection*)NULL;
		}
	virtual const RealPersistentCollection 
			&CastToRealPersistentCollection(void) const
		{ throw LogiconErrors::InvalidType(
				"Reference::CastToRealPersistentCollection()"); 
		  return *(RealPersistentCollection*)NULL;
		}
};


#endif
