//
// Module Name:		cmcReferenceCache.h
//
// CSCI/CSC/CSU:	CMC/ReferenceCache
//
// Author:		Joe Dzikiewicz
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	Includes for ReferenceCache.  A ReferenceCache maintains a set of
//	references, caching them for future use.  The purpose of this is
//	so that, within a process, a given object can be opened in two
//	places with both referring to the same copy of the object.  Each
//	location thinks it is dealing with the actual object, but each
//	is only using a shell that has a reference to the object.  The
//	actual object is kept in the ReferenceCache.
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           2/22/96     jd_2     Initial Version
//

#ifndef _cmcReferenceCache_h
#define _cmcReferenceCache_h

#include "cmcSet.h"
#include "cmcReference.h"

class ReferenceCache
{
    private:
    	Set<Reference> Container;		// container of data

	int FindOffset(const char *Name);	// find the offset to Name
	int FindOffset(const Reference &Target);// find the offset to Target

    public:
	Reference *GetReference(const char *Name);
						// find the item with Name
						// this does NOT return
						//     ownership of the item
						// return NULL if not found
	void DropReference(Reference &Target);	// drop a reference to Name
	void AddReference(Reference *pNewContents);
						// add an item
};


#endif
