//
// Module Name:		cmcSecSurrogate.cc
//
// CSCI/CSC/CSU:	CMC/SecSurrogate
//
// Author:		Joe Dzikiewicz
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//			RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	Code for a SecSurrogate.  A SecSurrogate is a wrapper placed around
//	a SEC object so that the object can be manipulated by CMC functions
//	(in particular, so that it can be stored in Sets and destructed by
//	the Set destructors.)
//
// Function List:
//	SecSurrogate::SecSurrogate() - Constructor
//	SecSurrogate::~SecSurrogate() - Destructor
//	SecSurrogate::GetData() - Get the underlying item from this
//	SecSurrogate::ExtractData() - Extract the underlying item from this
//	SecSurrogate::GetClass() - Get the class label of this
//
// Other Modules Called:
//	None
//
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           1/3/96      jd_2     Initial version
//


#include <stddef.h>		// for NULL

#include "cmcSecSurrogate.h"	// declarations for this

// the following is the label for a SecSurrogate
const char *SecSurrogate::ClassLabel = "SecSurrogate";

//
// Function Name:	SecSurrogate::SecSurrogate()
//
// CSCI/CSC/CSU:	CMC/SecSurrogate
//
// Description:		Constructor.
//
// Parameters:		pNewData - SEC item for which this is a surrogate
//
// Return Value:	None
//
SecSurrogate::SecSurrogate(void *pNewData) : pData(pNewData)
{
}


//
// Function Name:	SecSurrogate::~SecSurrogate()
//
// CSCI/CSC/CSU:	CMC/SecSurrogate
//
// Description:		Destructor
//
// Parameters:		None
//
// Return Value:	None
//
SecSurrogate::~SecSurrogate()
{
   // if(pData != NULL)
   // ::Free(pData);
}



//
// Function Name:	SecSurrogate::GetData()
//
// CSCI/CSC/CSU:	CMC/SecSurrogate
//
// Description:		Get the item for which this is a surrogate.
//
// Parameters:		None
//
// Return Value:	The pData component
//
const void *SecSurrogate::GetData(void) const
{
    return pData;
}



//
// Function Name:	SecSurrogate::ExtractData()
//
// CSCI/CSC/CSU:	CMC/SecSurrogate
//
// Description:		Extract the item for which this is a surrogate, 
//			taking over ownership of it.
//
// Parameters:		None
//
// Return Value:	The pData component
//
void *SecSurrogate::ExtractData(void)
{
    void *pReturn = pData;		// return value

    pData = NULL;

    return pReturn;
}


//
// Function Name:	SecSurrogate::GetClass()
//
// CSCI/CSC/CSU:	CMC/SecSurrogate
//
// Description:		Get the class label for this.
//
// Parameters:		None
//
// Return Value:	"SecSurrogate"
//
const char *SecSurrogate::GetClass() const
{
    return ClassLabel;
}



