//
//
// Module Name:		cmcSequenceValue.h
//
// CSCI/CSC/CSU:	CMC/SequenceValue
//
// Author:		Ken Kolda
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	.h for SequenceValue.  A SequenceValue is a type of AttributeValue
//	that has as value a set of other AttributeValues.
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           11/17/95    kolda    Initial version
//

#ifndef _cmcSequenceValue_h
#define _cmcSequenceValue_h

#include <iostream.h>			// to allow I/O to streams

class SequenceValue;

#include "cmcSet.h"			// To keep its values
#include "cmcAttributeValue.h"		// SequenceValue is a AttributeValue
#include "cmcAttributeValueType.h"	// to get enumerated type
#include "cmcDocMgrObject.h"		// Has a base class of this

// SequenceValue is a set of other Attributes
#ifndef __GNUG__
class SequenceValue : public AttributeValue, public DocumentManagerObject
#else
class SequenceValue : public AttributeValue
#endif

{
  private:
	Set<AttributeValue> Value;		// Set of attributes that make
						// up this attribute's value
	int Changed;				// changed flag

  public:
	// TIPSTER functions
	SequenceValue(const Set<AttributeValue>&);
						// Constructor
	~SequenceValue(void);			// Destructor
	const Set<AttributeValue> &GetValue(void) const;
						// Returns reference to
	Set<AttributeValue> &GetValue(void); 	// Returns reference to 
						// in non-const way
	AttributeValueType TypeOf(void) const;	// Returns "SEQUENCE_VALUE"

	// TIPSTER additions
	static const char *ClassLabel;		// The name of this class
	
	SequenceValue(istream&);		// Construct from reading in
						// the Value component
	AttributeValue *Copy(void) const;	// Return copy of this
	virtual void WriteToStream(ostream&) const;
						// Write this to output
	virtual int operator==(const AttributeValue&) const;
						// test equality
	virtual int IsChanged(void) const;	// test changed status
	virtual void ClearChanged(void);	// clear changed status

	virtual const char *GetClass(void) const;
						// Get the class of this
	SequenceValue &CastToSequenceValue(void);
						// downcast function
	const SequenceValue &CastToSequenceValue(void) const;
						// downcast function
};

#endif
