//
// Module Name:		cmcSet.h
//
// CSCI/CSC/CSU:	CMC/Set<X>
//
// Author:		Ken Kolda
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	Provide the class definition for a Set<X> template class.  A
//	Set<X> maintains a sequence of some data elements.
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           11/14/95    kolda   Initial version
//

#ifndef _cmcSet_h
#define _cmcSet_h

#include "cmcDocMgrObject.h"	// Has a base class of this

// Set is a template for general sets of objects
template <class X> class Set : public DocumentManagerObject
{
   private:
	X **ppData;		// Pointers to elements of the set
    	int Size;		// The number of elements in set
	int AllocatedSize;  	// Number of elements spaces allocated in set
	int Changed;		// Changed status of set

	void Expand(void);	// expand the storage in the set

   public:
	// TIPSTER functions
	Set(void);  		// Constructor
	~Set(void);		// Destructor
	X &Nth(int i) const;	// Returns Nth item in set
	void Push(X *pItem);	// Adds pItem to the set
	X *Pop(void);		// Pops last item from end of set and 
				// returns it
	int Length(void) const;	// Returns the Size component

	// TIPSTER additions
#ifndef __GNUG__
	static const char *ClassLabel;
#else
	char *ClassLabel;
#endif
				// name of this class

	X *PopNth(int N);	// Pops Nth item from the set and returns it
	void Sort(int (*pComparisonFunction)(X**, X**));
				// Sorts the items in the set using the given
				// ComparisonFunction
				// Does NOT take ownership of 
				//	pComparisonFunction
	void Delete(int i);	// Deletes ith element of the set
	void Replace(int i, X *pItem);
				// Replace I'th item with pItem
	void Insert(int i, X *pItem);
				// Adds pItem to the set in position i
	int IsChanged(void) const;
				// check changed status of this
	void ClearChanged(void);
				// clear changed status of this

	virtual const char *GetClass(void) const;
				// Get the class of this
};

#endif
