//
// Module Name:		cmcSpan.h
//
// CSCI/CSC/CSU:	CMC/Span
//
// Author:		Ken Kolda
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	Provide the class definition for Span.  A Span describes the
//	start and end offsets of a section of text.
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           11/14/95    kolda    Initial version
//

#ifndef _cmcSpan_h
#define _cmcSpan_h

#include <iostream.h>		// to allow I/O to streams

#include "cmcDocMgrObject.h"	// Has a base class of this

// Span is simply a starting and ending byte offset in a Document
class Span : public DocumentManagerObject
{
    private:
	int Start;			// Starting offset
	int End;			// Ending offset

    public:
	// TIPSTER functions
	Span(int NewStart, int NewEnd);	// Constructor
	~Span(void) {}			// empty virtual destructor
	int GetStart(void) const;	// Returns Start component
	int GetEnd(void) const;		// Returns End component

	// TIPSTER additions
	static const char *ClassLabel;	// The name of this class
	
	Span(istream&);			// construct from input
	void WriteToStream(ostream&) const;
					// write span to output
	virtual const char *GetClass(void) const;
					// Get the class of this
	virtual Span &CastToSpan(void);	// downcast function
	virtual const Span &CastToSpan(void) const;
					// downcast function
};


// the following are related functions
ostream &operator<<(ostream&, Span&);

#endif
