//
// Module Name:		cmcStringValue.h
//
// CSCI/CSC/CSU:	CMC/StringValue
//
// Author:		Ken Kolda
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	Provide the class definition for StringValue.  A StringValue is a
//	type of AttributeValue that has a string as a value.
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           11/14/95    kolda    Initial version
//
//

#ifndef _cmcStringValue_h
#define _cmcStringValue_h

#include <iostream.h>			// to allow I/O to streams

#include "cmcAttributeValueType.h"	// Has enumerated type of AttributeValue
#include "cmcAttributeValue.h"		// StringValue is a AttributeValue
#include "cmcDocMgrObject.h"		// Has a base class of this

// StringValue permits strings as attributes
#ifndef __GNUG__
class StringValue : public AttributeValue, public DocumentManagerObject
#else 
class StringValue : public AttributeValue
#endif
{
  private:
	char *Value;			// The value of this attribute

  public:
	// TIPSTER functions
	StringValue(const char*);	// Constructor
	~StringValue(void);		// Destructor
	const char *GetValue(void) const;
					// Returns the Value component
	AttributeValueType TypeOf(void) const;
					// Returns "String" type

	// TIPSTER additions
	static const char *ClassLabel;	// The name of this class
	
	StringValue(istream &);		// Construct from reading from file
	AttributeValue *Copy(void) const;
					// Return copy of this
	void WriteToStream(ostream&) const;
					// Write out this to a stream
	virtual int operator==(const AttributeValue&) const;
					// test equality
	const char *GetClass(void) const;
					// Get the class of this
	virtual StringValue &CastToStringValue(void);
					// downcast function
	virtual const StringValue &CastToStringValue(void) const;
					// downcast function
};

#endif

