//
// Module Name:		cmcTipsterCSet.h
//
// CSCI/CSC/CSU:	CMC/TipsterCSet
//
// Author:		Joe Dzikiewicz
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	.h for TipsterCSet.  A TipsterCSet is a wrapper around a Set.  It's
//	purpose is to support the C binding for sets by tracking the type
//	of data in the set.
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           12/15/95    jd_2     Initial version
//

#ifndef _cmcTipsterCSet_h
#define _cmcTipsterCSet_h

#include "cmcDocMgrObject.h"		// base class for this
#include "cmcSet.h"			// this keeps various sets
#include "cmcSpan.h"			// this keeps set of Spans
#include "cmcAttribute.h"		// this keeps set of Attributes
#include "cmcAttributeValue.h"		// this keeps set of AttributeValues
#include "cmcSecSurrogate.h"		// this keeps set of SecSurrogates
	
class TipsterCSet : public DocumentManagerObject
{
    private:
	Set<char *> *pStringSet;	// set of strings
	Set<Attribute> *pAttributeSet;	// set of Attributes
	Set<AttributeValue> *pAttributeValueSet;
					// set of AttributeValues
	Set<Span> *pSpanSet;		// set of Spans
	Set<SecSurrogate> *pSecSurrogateSet;
					// set of surrogates

    public:
	// TIPSTER functions
	~TipsterCSet(void);		// destructor
	int Length(void) const;		// length of the set
	void *Nth(int N) const;		// Nth item in the set
	void *Pop(void);		// Pop last item from set
	void Push(void *pData);		// push pData to set

	// TIPSTER additions
	TipsterCSet(Set<Span>*);	// construct for Span set,
					//	taking it over
	TipsterCSet(Set<char *>*);	// construct for string set,
					//	taking it over
	TipsterCSet(Set<Attribute>*);	// construct for Attribute set,
					// 	taking it over
	TipsterCSet(Set<AttributeValue>*);
					// construct for AttributeValue set,
					//	taking it over
	TipsterCSet(Set<SecSurrogate>*);
					// construct for SecSurrogate set,
					//	taking it over

	TipsterCSet(Set<Span>&);	// construct for Span set,
					//	copying it
	TipsterCSet(Set<char *>&);	// construct for string set,
					//	copying it
	TipsterCSet(Set<Attribute>&);	// construct for Attribute set
					//	copying it
	TipsterCSet(Set<AttributeValue>&);
					// construct for AttributeValue set,
					//	copying it

	static const char *ClassLabel;	// name of this class

	Set<char *> &GetStringSet(void) const;
					// get the pStringSet component
	Set<Attribute> &GetAttributeSet(void) const;
					// get the pAttributeSet component
	Set<AttributeValue> &GetAttributeValueSet(void) const;
					// get the pAttributeValueSet component
	Set<SecSurrogate> &GetSecSurrogateSet(void) const;
					// get the pSecSurrogateSet component
	Set<Span> &GetSpanSet(void) const;
					// get the pSpanSet component
	const char *GetClass(void) const;
					// return class of this
	virtual TipsterCSet &CastToTipsterCSet(void);
					// downcast function
	virtual const TipsterCSet &CastToTipsterCSet(void) const;
					// downcast function
};

#endif
