//
// Module Name:		cmcVolatileCollection.h
//
// CSCI/CSC/CSU:	CMC/VolatileCollection
//
// Author:		Ken Kolda
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	This contains the class definition for VolatileCollection.  A
//	VolatileCollection is a type of Collection that exists only in
//	volatile storage.
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           11/28/95    kolda    Initial version
//

#ifndef _cmcVolatileCollection_h
#define _cmcVolatileCollection_h

#include "cmcSet.h"			// Documents are kept in Sets
#include "cmcAttribute.h"		// Attributes of the Collection are kept
#include "cmcDocument.h"		// Documents are stored herein
#include "cmcCollection.h"		// VolatileCollection is a Collection
#include "cmcPersistentCollection.h"	// VolatileCollection can make a
					//     PersistentCollection
#include "cmcDocumentId.h"		// for testing the ID's

// VolatileCollection maintains a memory-only Collection object
class VolatileCollection : public Collection
{
  private:
	Set<Document> Contents;		// The Documents in the Collection
	int NextDocumentIndex;		// Next Document to Retrieve
	int NextDocumentId;		// Next ID to Assign to a Document
	int BasePtrValue;		// base pointer value when this
					//	was first constructed

	const char *MakeId(void);	// construct a Document ID
	int IsFromThisCollection(const DocumentId &) const;
					// test if a DocumentId is associated 
					// 	with this Collection
	int FindDocument(const char *Id) const;
					// find a Document's offset

  public:
	// TIPSTER functions
	VolatileCollection(const Set<Attribute> &NewAttributes);
					// Constructor
	virtual ~VolatileCollection(void);
					// destructor
	int Length(void) const;		// Number of Documents in Collection
	void RemoveDocument(const char *Id);
					// Removes Document from Collection
	Document *GetDocument(const char *Id);
					// Returns Document with given ID
	Document *FirstDocument(void);	// Returns first Document in Collection
	Document *NextDocument(void);	// Returns next Document in Collection
	Document *GetByExternalId(const char *ExternalId);
					// Returns Document with given 
					// External ID
	void AnnotateCollection(Collection &Which, const char *AnnotatorName);
					// Annotates Documents in Collection
	void Sync(void) {}		// Does nothing
	void Store(Document &NewDocument);
					// Stores Document in Collection
	void Update(Document &NewDocument);
					// Updates Document in Collection

	// TIPSTER additions
	PersistentCollection *MakePersistent(const char *Name) const;
					// Creates a Persistent Collection
					// from this Volatile Collection
};

#endif

