//
// Module Name:		cmcVolume.h
//
// CSCI/CSC/CSU:	CMC/Volume
//
// Author:		Ken Kolda
//			Logicon ITG
//			2100 Washington Boulevard
//			Arlington, VA 22204
//
// Security:		Unclassified
//
//		RESTRICTED RIGHTS LEGEND
//
// Use, duplication, or disclosure by the Government is subject to
// restrictions as set forth in subdivision (b) (3) (iii) of the Rights
// in Technical Data and Computer Software clause at 52.227-7013.
//
//	Logicon, Inc., 2100 Washington Blvd., Arlington, VA 22204-5703
//
// Description:
//	This contains the class definition for Volume.  A Volume maintains
//	a file of Documents.  It uses a RecordFile for its underlying
//	storage.
//
// Maintenance History
// Version	Date	Userid		Description of changes
// =======  =========== ======== ===========================================
//           11/28/95    kolda    Initial version
//

#ifndef _cmcVolume_h
#define _cmcVolume_h

class Volume;                           // Incomplete Declaration

#include "cmcSet.h"			// Attributes are kept in Sets
#include "cmcAttribute.h"		// This tracks stored Attributes
#include "cmcRecordFile.h"		// RecordFiles provide storage
#include "cmcDocument.h"		// Documents are stored by Volumes
#include "cmcCollection.h"		// Volume needs to track its Collection
#include "cmcAttributedObject.h"	// Volume is one of these

// Volume is a group of Documents that makes up a Collection
class Volume : public AttributedObject
{
  private:
	Collection &Parent;		// parent collection of this
	RecordFile File;		// The data file for the volume
	int DocumentCount;		// Number of Documents in Volume
	int VolumeCount;		// Number of Volumes in Collection
	char *Name;			// Name of Volume
	int VolumeNo;			// Offset of the Volume
	int HeaderChanged;		// flag indicating if header has changed

	static const char *GetFilename(const char *, int);
					// get a Volume's filename
	void WriteHeader(void);		// write out the Volume's header
	void ReadHeader(void);		// read in the Volume's header
	void Cleanup(void);		// clean this guy up

  public:
	// an Iterator is used during a walkthrough
	class Iterator 
	{
	    private:
		RecordFile::Iterator Value;	// to hold the actual iterator

		friend Volume;			// to note friendship
	};

	Volume(Collection &NewParent, const char *NewName, int NewOffset);
					// Constructor for Stored Volume
	Volume(Collection &NewParent, const char *NewName, 
		const Set<Attribute> &NewAttributes, int NewOffset, 
		int BlockSize, int NewVolumeCount);	
					// Constructor for New Volume
	~Volume(void);			// destructor
	int GetVolumeCount(void) const;	// Returns the VolumeCount component
	int Length(void) const;		// Returns Number of Documents in
					// Volume
	char *RemoveDocument(int Offset, const char *Id);
					// Removes Document at Offset,
					// returning its External ID
					// and testing that it has ID Id
	Document *GetDocument(int Offset, const char *Id = NULL);
					// Returns Document at Offset
					// and check that it has ID Id
	Document *NextDocument(Iterator&);
					// Retrieves next Document in Volume
	static void Destroy(const char *TargetName, int TargetVolumeNo);
					// destroy the named Volume
	void Store(Document &NewDocument);
					// Stores Document in Volume
	char *Store(Document &NewDocument, int Offset);
					// Stores Document to a position 
					// indicated by Offset returning
					// the ExternalId of the Document
					// currently there
	void Sync(void);		// synchronize changes to file

	virtual void PutAttribute(const char *AttributeName, 
				  const AttributeValue &Value);
					// Stores the named Attribute in Volume
};

#endif
