#include <stddef.h>
#include <string.h>

#include "cmcDocument.h"
#include "cmcSet.h"

#ifndef __GNUG__

class SpanPlace
{
    private:
	int Place;
	char Action[100];
	char Id[100];
    public:
	SpanPlace(int NewPlace, const char *NewAction, const char *NewId) 
				: Place(NewPlace)
			{ strcpy(Id, NewId); strcpy(Action, NewAction); }
	int GetPlace() { return Place; }
	char *GetId() { return Id; }
	char *GetAction() { return Action; }
};
#else
#include "docdisplay.h"
#endif

static int CompareSpanPlace(SpanPlace **p1, SpanPlace **p2);
static void ShowAnnotatedText(Document &Doc);
static void ShowAttribute(Attribute &Attr);
static void ShowAnnotation(Annotation &Annot);



static int CompareSpanPlace(SpanPlace **p1, SpanPlace **p2)
{
    return((*p1)->GetPlace() > (*p2)->GetPlace());
}


void ShowDocument(Document &Doc)
{
    int i;			// loop index

    // display the IDs
    cout << "ID: " << Doc.GetId() << "\n";
    cout << "External Id: " << Doc.GetExternalId() << "\n";

    // display the attributes
    cout << "Attributes:\n";
    for(i = 0; i < Doc.GetAttributes().Length(); ++i)
    {
	ShowAttribute(Doc.GetAttributes().Nth(i));
    }

    // display the annotations
    cout << "\nAnnotations:\n";
    for(i = 0; i < Doc.GetAnnotations().Length(); ++i)
	ShowAnnotation(Doc.GetAnnotations().Nth(i));

    // display an annotated document text
    int CurPlace = 0;
    cout << "\nAnnotated text:\n";
    ShowAnnotatedText(Doc);
}




static void ShowAnnotatedText(Document &Doc)
{
    Set<SpanPlace> Places;

    if(Doc.GetRawData() == NULL)
    {
	cout << "No text available\n";
	return;
    }

    int i;
    for(i = 0; i < Doc.GetAnnotations().Length(); ++i)
    {
	for(int j = 0; j < Doc.GetAnnotations().Nth(i).GetSpans().Length(); ++j)
	{
	    Places.Push(new SpanPlace(
		Doc.GetAnnotations().Nth(i).GetSpans().Nth(j).GetStart(),
		"START",
		Doc.GetAnnotations().Nth(i).GetId()));
	    Places.Push(new SpanPlace(
		Doc.GetAnnotations().Nth(i).GetSpans().Nth(j).GetEnd(),
		"END",
		Doc.GetAnnotations().Nth(i).GetId()));
	}
    }

    Places.Sort(CompareSpanPlace);

    int CurPlace = 0;
    for(i = 0; i < Doc.GetRawData()->Length(); ++i)
    {
	// mark all locations here
	while(CurPlace < Places.Length() && 
			Places.Nth(CurPlace).GetPlace() == i)
	{
	    cout << "||" << Places.Nth(CurPlace).GetAction() << " " <<
			Places.Nth(CurPlace).GetId() << "||";
	    ++CurPlace;
	}

	cout << Doc.GetRawData()->ConvertToString()[i];
    }

    // display all ending tags
    while(CurPlace < Places.Length())
    {
	cout << "||" << Places.Nth(CurPlace).GetAction() << " " <<
			Places.Nth(CurPlace).GetId() << "||";
	++CurPlace;
    }
}

static void ShowAttribute(Attribute &Attr)
{
    cout << "\t" << Attr.GetName() << " = " << Attr.GetValue() << "\n";
}



static void ShowAnnotation(Annotation &Annot)
{
    cout << "\t" << Annot.GetId() << " " << Annot.GetType() << "\n";
    for(int i = 0; i < Annot.GetSpans().Length(); ++i)
    {
	cout << "\t\t<" << Annot.GetSpans().Nth(i).GetStart() <<
		", " << Annot.GetSpans().Nth(i).GetEnd() << ">\n";
    }
    for(int j=0; j<Annot.GetAttributes().Length(); ++j)
    {
	ShowAttribute(Annot.GetAttributes().Nth(j));
    }
    cout << "\n";
}
